aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--data/constants/keycodes/extras/keycodes_eurkey_0.0.1.hjson596
-rw-r--r--data/constants/keycodes/extras/keycodes_farsi_0.0.1.hjson2
-rw-r--r--data/mappings/keyboard_aliases.hjson6
-rw-r--r--docs/features/leader_key.md15
-rw-r--r--docs/reference_keymap_extras.md1
-rw-r--r--keyboards/cxt_studio/12e4/config.h6
-rw-r--r--keyboards/cxt_studio/12e4/cxt_studio.c (renamed from keyboards/cxt_studio/cxt_studio.c)20
-rw-r--r--keyboards/cxt_studio/12e4/keyboard.json (renamed from keyboards/cxt_studio/keyboard.json)2
-rw-r--r--keyboards/cxt_studio/12e4/keymaps/default/keymap.json (renamed from keyboards/cxt_studio/keymaps/default/keymap.json)2
-rw-r--r--keyboards/cxt_studio/12e4/readme.md (renamed from keyboards/cxt_studio/readme.md)10
-rw-r--r--keyboards/cxt_studio/config.h22
-rw-r--r--keyboards/kradoindustries/promenade/keyboard.json10
-rw-r--r--keyboards/kradoindustries/promenade/keymaps/default/keymap.c20
-rw-r--r--keyboards/kradoindustries/promenade/matrix_diagram.md8
-rw-r--r--keyboards/moky/moky88/config.h3
-rw-r--r--keyboards/moky/moky88/moky88.c176
-rw-r--r--keyboards/silakka54/config.h25
-rw-r--r--keyboards/silakka54/keyboard.json102
-rw-r--r--keyboards/silakka54/keymaps/default/keymap.c22
-rw-r--r--keyboards/silakka54/readme.md26
-rw-r--r--keyboards/skyloong/gk61/pro/config.h3
-rw-r--r--keyboards/skyloong/gk61/pro/pro.c149
-rw-r--r--keyboards/skyloong/gk61/pro_48/config.h4
-rw-r--r--keyboards/skyloong/gk61/pro_48/pro_48.c93
-rw-r--r--keyboards/ymdk/id75/f103/board.h (renamed from keyboards/ymdk/id75/board.h)0
-rw-r--r--keyboards/ymdk/id75/f103/config.h (renamed from keyboards/ymdk/id75/config.h)0
-rw-r--r--keyboards/ymdk/id75/f103/halconf.h (renamed from keyboards/ymdk/id75/halconf.h)0
-rw-r--r--keyboards/ymdk/id75/f103/keyboard.json13
-rw-r--r--keyboards/ymdk/id75/f103/mcuconf.h (renamed from keyboards/ymdk/id75/mcuconf.h)0
-rw-r--r--keyboards/ymdk/id75/f103/rules.mk (renamed from keyboards/ymdk/id75/rules.mk)0
-rw-r--r--keyboards/ymdk/id75/info.json (renamed from keyboards/ymdk/id75/keyboard.json)231
-rw-r--r--keyboards/ymdk/id75/readme.md12
m---------lib/chibios0
m---------lib/chibios-contrib0
-rwxr-xr-xlib/python/qmk/cli/generate/keyboard_h.py19
-rwxr-xr-xlib/python/qmk/cli/new/keymap.py6
-rw-r--r--platforms/chibios/boards/GENERIC_STM32_H723XG/configs/mcuconf.h2
-rw-r--r--platforms/chibios/boards/QMK_PROTON_C/configs/chconf.h23
-rw-r--r--platforms/chibios/boards/common/configs/chconf.h23
-rw-r--r--platforms/chibios/drivers/audio_pwm_hardware.c18
-rw-r--r--platforms/chibios/timer.c4
-rw-r--r--platforms/timer.h7
-rw-r--r--quantum/audio/audio.c5
-rw-r--r--quantum/keymap_extras/keymap_eurkey.h166
-rw-r--r--quantum/keymap_extras/keymap_farsi.h2
-rw-r--r--quantum/leader.c7
-rw-r--r--quantum/leader.h9
-rw-r--r--quantum/painter/qgf.c8
-rw-r--r--quantum/painter/qp_draw_image.c6
-rw-r--r--quantum/rgb_matrix/animations/hue_breathing_anim.h22
-rw-r--r--quantum/rgb_matrix/animations/raindrops_anim.h29
-rw-r--r--quantum/rgb_matrix/animations/starlight_anim.h29
-rw-r--r--quantum/rgb_matrix/animations/starlight_dual_hue_anim.h31
-rw-r--r--quantum/rgb_matrix/animations/starlight_dual_sat_anim.h31
-rw-r--r--readme.md4
-rw-r--r--tmk_core/protocol/chibios/usb_main.c8
56 files changed, 1441 insertions, 597 deletions
diff --git a/data/constants/keycodes/extras/keycodes_eurkey_0.0.1.hjson b/data/constants/keycodes/extras/keycodes_eurkey_0.0.1.hjson
new file mode 100644
index 0000000000..9ff217cff2
--- /dev/null
+++ b/data/constants/keycodes/extras/keycodes_eurkey_0.0.1.hjson
@@ -0,0 +1,596 @@
+{
+ "aliases": {
+/*
+ * ┌───┬───┬───┬───┬───┬───┬───┬───┬───┬───┬───┬───┬───┬───────┐
+ * │ ` │ 1 │ 2 │ 3 │ 4 │ 5 │ 6 │ 7 │ 8 │ 9 │ 0 │ - │ = │ │
+ * ├───┴─┬─┴─┬─┴─┬─┴─┬─┴─┬─┴─┬─┴─┬─┴─┬─┴─┬─┴─┬─┴─┬─┴─┬─┴─┬─────┤
+ * │ │ Q │ W │ E │ R │ T │ Y │ U │ I │ O │ P │ [ │ ] │ \ │
+ * ├─────┴┬──┴┬──┴┬──┴┬──┴┬──┴┬──┴┬──┴┬──┴┬──┴┬──┴┬──┴┬──┴─────┤
+ * │ │ A │ S │ D │ F │ G │ H │ J │ K │ L │ ; │ ' │ │
+ * ├──────┴─┬─┴─┬─┴─┬─┴─┬─┴─┬─┴─┬─┴─┬─┴─┬─┴─┬─┴─┬─┴─┬─┴────────┤
+ * │ │ Z │ X │ C │ V │ B │ N │ M │ , │ . │ / │ │
+ * ├────┬───┴┬──┴─┬─┴───┴───┴───┴───┴───┴──┬┴───┼───┴┬────┬────┤
+ * │ │ │ │ │ │ │ │ │
+ * └────┴────┴────┴────────────────────────┴────┴────┴────┴────┘
+ */
+ "KC_GRV": {
+ "key": "EU_GRV",
+ "label": "`",
+ }
+ "KC_1": {
+ "key": "EU_1",
+ "label": "1",
+ }
+ "KC_2": {
+ "key": "EU_2",
+ "label": "2",
+ }
+ "KC_3": {
+ "key": "EU_3",
+ "label": "3",
+ }
+ "KC_4": {
+ "key": "EU_4",
+ "label": "4",
+ }
+ "KC_5": {
+ "key": "EU_5",
+ "label": "5",
+ }
+ "KC_6": {
+ "key": "EU_6",
+ "label": "6",
+ }
+ "KC_7": {
+ "key": "EU_7",
+ "label": "7",
+ }
+ "KC_8": {
+ "key": "EU_8",
+ "label": "8",
+ }
+ "KC_9": {
+ "key": "EU_9",
+ "label": "9",
+ }
+ "KC_0": {
+ "key": "EU_0",
+ "label": "0",
+ }
+ "KC_MINS": {
+ "key": "EU_MINS",
+ "label": "-",
+ }
+ "KC_EQL": {
+ "key": "EU_EQL",
+ "label": "=",
+ }
+ "KC_Q": {
+ "key": "EU_Q",
+ "label": "Q",
+ }
+ "KC_W": {
+ "key": "EU_W",
+ "label": "W",
+ }
+ "KC_E": {
+ "key": "EU_E",
+ "label": "E",
+ }
+ "KC_R": {
+ "key": "EU_R",
+ "label": "R",
+ }
+ "KC_T": {
+ "key": "EU_T",
+ "label": "T",
+ }
+ "KC_Y": {
+ "key": "EU_Y",
+ "label": "Y",
+ }
+ "KC_U": {
+ "key": "EU_U",
+ "label": "U",
+ }
+ "KC_I": {
+ "key": "EU_I",
+ "label": "I",
+ }
+ "KC_O": {
+ "key": "EU_O",
+ "label": "O",
+ }
+ "KC_P": {
+ "key": "EU_P",
+ "label": "P",
+ }
+ "KC_LBRC": {
+ "key": "EU_LBRC",
+ "label": "[",
+ }
+ "KC_RBRC": {
+ "key": "EU_RBRC",
+ "label": "]",
+ }
+ "KC_BSLS": {
+ "key": "EU_BSLS",
+ "label": "\\",
+ }
+ "KC_A": {
+ "key": "EU_A",
+ "label": "A",
+ }
+ "KC_S": {
+ "key": "EU_S",
+ "label": "S",
+ }
+ "KC_D": {
+ "key": "EU_D",
+ "label": "D",
+ }
+ "KC_F": {
+ "key": "EU_F",
+ "label": "F",
+ }
+ "KC_G": {
+ "key": "EU_G",
+ "label": "G",
+ }
+ "KC_H": {
+ "key": "EU_H",
+ "label": "H",
+ }
+ "KC_J": {
+ "key": "EU_J",
+ "label": "J",
+ }
+ "KC_K": {
+ "key": "EU_K",
+ "label": "K",
+ }
+ "KC_L": {
+ "key": "EU_L",
+ "label": "L",
+ }
+ "KC_SCLN": {
+ "key": "EU_SCLN",
+ "label": ";",
+ }
+ "KC_QUOT": {
+ "key": "EU_QUOT",
+ "label": "'",
+ }
+ "KC_Z": {
+ "key": "EU_Z",
+ "label": "Z",
+ }
+ "KC_X": {
+ "key": "EU_X",
+ "label": "X",
+ }
+ "KC_C": {
+ "key": "EU_C",
+ "label": "C",
+ }
+ "KC_V": {
+ "key": "EU_V",
+ "label": "V",
+ }
+ "KC_B": {
+ "key": "EU_B",
+ "label": "B",
+ }
+ "KC_N": {
+ "key": "EU_N",
+ "label": "N",
+ }
+ "KC_M": {
+ "key": "EU_M",
+ "label": "M",
+ }
+ "KC_COMM": {
+ "key": "EU_COMM",
+ "label": ",",
+ }
+ "KC_DOT": {
+ "key": "EU_DOT",
+ "label": ".",
+ }
+ "KC_SLSH": {
+ "key": "EU_SLSH",
+ "label": "/",
+ }
+/* Shifted symbols
+ * ┌───┬───┬───┬───┬───┬───┬───┬───┬───┬───┬───┬───┬───┬───────┐
+ * │ ~ │ ! │ @ │ # │ $ │ % │ ^ │ & │ * │ ( │ ) │ _ │ + │ │
+ * ├───┴─┬─┴─┬─┴─┬─┴─┬─┴─┬─┴─┬─┴─┬─┴─┬─┴─┬─┴─┬─┴─┬─┴─┬─┴─┬─────┤
+ * │ │ │ │ │ │ │ │ │ │ │ │ { │ } │ | │
+ * ├─────┴┬──┴┬──┴┬──┴┬──┴┬──┴┬──┴┬──┴┬──┴┬──┴┬──┴┬──┴┬──┴─────┤
+ * │ │ │ │ │ │ │ │ │ │ │ : │ " │ │
+ * ├──────┴─┬─┴─┬─┴─┬─┴─┬─┴─┬─┴─┬─┴─┬─┴─┬─┴─┬─┴─┬─┴─┬─┴────────┤
+ * │ │ │ │ │ │ │ │ │ < │ > │ ? │ │
+ * ├────┬───┴┬──┴─┬─┴───┴───┴───┴───┴───┴──┬┴───┼───┴┬────┬────┤
+ * │ │ │ │ │ │ │ │ │
+ * └────┴────┴────┴────────────────────────┴────┴────┴────┴────┘
+ */
+ "S(EU_GRV)": {
+ "key": "EU_TILD",
+ "label": "~",
+ }
+ "S(EU_1)": {
+ "key": "EU_EXLM",
+ "label": "!",
+ }
+ "S(EU_2)": {
+ "key": "EU_AT",
+ "label": "@",
+ }
+ "S(EU_3)": {
+ "key": "EU_HASH",
+ "label": "#",
+ }
+ "S(EU_4)": {
+ "key": "EU_DLR",
+ "label": "$",
+ }
+ "S(EU_5)": {
+ "key": "EU_PERC",
+ "label": "%",
+ }
+ "S(EU_6)": {
+ "key": "EU_CIRC",
+ "label": "^",
+ }
+ "S(EU_7)": {
+ "key": "EU_AMPR",
+ "label": "&",
+ }
+ "S(EU_8)": {
+ "key": "EU_ASTR",
+ "label": "*",
+ }
+ "S(EU_9)": {
+ "key": "EU_LPRN",
+ "label": "(",
+ }
+ "S(EU_0)": {
+ "key": "EU_RPRN",
+ "label": ")",
+ }
+ "S(EU_MINS)": {
+ "key": "EU_UNDS",
+ "label": "_",
+ }
+ "S(EU_EQL)": {
+ "key": "EU_PLUS",
+ "label": "+",
+ }
+ "S(EU_LBRC)": {
+ "key": "EU_LCBR",
+ "label": "{",
+ }
+ "S(EU_RBRC)": {
+ "key": "EU_RCBR",
+ "label": "}",
+ }
+ "S(EU_BSLS)": {
+ "key": "EU_PIPE",
+ "label": "|",
+ }
+ "S(EU_SCLN)": {
+ "key": "EU_COLN",
+ "label": ":",
+ }
+ "S(EU_QUOT)": {
+ "key": "EU_DQUO",
+ "label": "\"",
+ }
+ "S(EU_COMM)": {
+ "key": "EU_LABK",
+ "label": "<",
+ }
+ "S(EU_DOT)": {
+ "key": "EU_RABK",
+ "label": ">",
+ }
+ "S(EU_SLSH)": {
+ "key": "EU_QUES",
+ "label": "?",
+ }
+/* AltGr symbols
+ * ┌───┬───┬───┬───┬───┬───┬───┬───┬───┬───┬───┬───┬───┬───────┐
+ * │ ` │ ¡ │ ª │ º │ £ │ € │ ^ │ ˚ │ „ │ “ │ ” │ – │ × │ │
+ * ├───┴─┬─┴─┬─┴─┬─┴─┬─┴─┬─┴─┬─┴─┬─┴─┬─┴─┬─┴─┬─┴─┬─┴─┬─┴─┬─────┤
+ * │ │ æ │ å │ ë │ ý │ þ │ ÿ │ ü │ ï │ ö │ œ │ « │ » │ ¬ │
+ * ├─────┴┬──┴┬──┴┬──┴┬──┴┬──┴┬──┴┬──┴┬──┴┬──┴┬──┴┬──┴┬──┴─────┤
+ * │ │ ä │ ß │ ð │ è │ é │ ù │ ú │ ij │ ø │ ° │ ´ │ │
+ * ├──────┴─┬─┴─┬─┴─┬─┴─┬─┴─┬─┴─┬─┴─┬─┴─┬─┴─┬─┴─┬─┴─┬─┴────────┤
+ * │ │ à │ á │ ç │ ì │ í │ ñ │ μ │ ò │ ó │ ¿ │ │
+ * ├────┬───┴┬──┴─┬─┴───┴───┴───┴───┴───┴──┬┴───┼───┴┬────┬────┤
+ * │ │ │ │ │ │ │ │ │
+ * └────┴────┴────┴────────────────────────┴────┴────┴────┴────┘
+ */
+ "ALGR(EU_GRV)": {
+ "key": "EU_DGRV",
+ "label": "` (dead)",
+ }
+ "ALGR(EU_1)": {
+ "key": "EU_IEXL",
+ "label": "¡",
+ }
+ "ALGR(EU_2)": {
+ "key": "EU_FORD",
+ "label": "ª",
+ }
+ "ALGR(EU_3)": {
+ "key": "EU_MORD",
+ "label": "º",
+ }
+ "ALGR(EU_4)": {
+ "key": "EU_PND",
+ "label": "£",
+ }
+ "ALGR(EU_5)": {
+ "key": "EU_EURO",
+ "label": "€",
+ }
+ "ALGR(EU_6)": {
+ "key": "EU_DCIR",
+ "label": "^ (dead)",
+ }
+ "ALGR(EU_7)": {
+ "key": "EU_RNGA",
+ "label": "˚ (dead)",
+ }
+ "ALGR(EU_8)": {
+ "key": "EU_DLQU",
+ "label": "„",
+ }
+ "ALGR(EU_9)": {
+ "key": "EU_LDQU",
+ "label": "“",
+ }
+ "ALGR(EU_0)": {
+ "key": "EU_RDQU",
+ "label": "”",
+ }
+ "ALGR(EU_MINS)": {
+ "key": "EU_NDSH",
+ "label": "–",
+ }
+ "ALGR(EU_EQL)": {
+ "key": "EU_MUL",
+ "label": "×",
+ }
+ "ALGR(EU_Q)": {
+ "key": "EU_AE",
+ "label": "æ",
+ }
+ "ALGR(EU_W)": {
+ "key": "EU_ARNG",
+ "label": "Å",
+ }
+ "ALGR(EU_E)": {
+ "key": "EU_EDIA",
+ "label": "Ë",
+ }
+ "ALGR(EU_R)": {
+ "key": "EU_YACU",
+ "label": "Ý",
+ }
+ "ALGR(EU_T)": {
+ "key": "EU_THRN",
+ "label": "Þ",
+ }
+ "ALGR(EU_Y)": {
+ "key": "EU_YDIA",
+ "label": "Ÿ",
+ }
+ "ALGR(EU_U)": {
+ "key": "EU_UDIA",
+ "label": "Ü",
+ }
+ "ALGR(EU_I)": {
+ "key": "EU_IDIA",
+ "label": "Ï",
+ }
+ "ALGR(EU_O)": {
+ "key": "EU_ODIA",
+ "label": "Ö",
+ }
+ "ALGR(EU_P)": {
+ "key": "EU_OE",
+ "label": "Œ",
+ }
+ "ALGR(EU_LBRC)": {
+ "key": "EU_LDAQ",
+ "label": "«",
+ }
+ "ALGR(EU_RBRC)": {
+ "key": "EU_RDAQ",
+ "label": "»",
+ }
+ "ALGR(EU_BSLS)": {
+ "key": "EU_NOT",
+ "label": "¬",
+ }
+ "ALGR(EU_A)": {
+ "key": "EU_ADIA",
+ "label": "Ä",
+ }
+ "ALGR(EU_S)": {
+ "key": "EU_SS",
+ "label": "ß",
+ }
+ "ALGR(EU_D)": {
+ "key": "EU_ETH",
+ "label": "Ð",
+ }
+ "ALGR(EU_F)": {
+ "key": "EU_EGRV",
+ "label": "È",
+ }
+ "ALGR(EU_G)": {
+ "key": "EU_EACU",
+ "label": "É",
+ }
+ "ALGR(EU_H)": {
+ "key": "EU_UGRV",
+ "label": "Ù",
+ }
+ "ALGR(EU_J)": {
+ "key": "EU_UACU",
+ "label": "Ú",
+ }
+ "ALGR(EU_K)": {
+ "key": "EU_IJ",
+ "label": "IJ",
+ }
+ "ALGR(EU_L)": {
+ "key": "EU_OSTR",
+ "label": "Ø",
+ }
+ "ALGR(EU_SCLN)": {
+ "key": "EU_DEG",
+ "label": "°",
+ }
+ "ALGR(EU_QUOT)": {
+ "key": "EU_ACUT",
+ "label": "´ (dead)",
+ }
+ "ALGR(EU_Z)": {
+ "key": "EU_AGRV",
+ "label": "À",
+ }
+ "ALGR(EU_X)": {
+ "key": "EU_AACU",
+ "label": "Á",
+ }
+ "ALGR(EU_C)": {
+ "key": "EU_CCED",
+ "label": "Ç",
+ }
+ "ALGR(EU_V)": {
+ "key": "EU_IGRV",
+ "label": "Ì",
+ }
+ "ALGR(EU_B)": {
+ "key": "EU_IACU",
+ "label": "Í",
+ }
+ "ALGR(EU_N)": {
+ "key": "EU_NTIL",
+ "label": "Ñ",
+ }
+ "ALGR(EU_M)": {
+ "key": "EU_DGRK",
+ "label": "μ (dead Greek key)",
+ }
+ "ALGR(EU_COMM)": {
+ "key": "EU_OGRV",
+ "label": "Ò",
+ }
+ "ALGR(EU_DOT)": {
+ "key": "EU_OACU",
+ "label": "Ó",
+ }
+ "ALGR(EU_SLSH)": {
+ "key": "EU_IQUE",
+ "label": "¿",
+ }
+/* Shift+AltGr symbols
+ * ┌───┬───┬───┬───┬───┬───┬───┬───┬───┬───┬───┬───┬───┬───────┐
+ * │ ~ │ ¹ │ ² │ ³ │ ¥ │ ¢ │ ˇ │ ¯ │ ‚ │ ‘ │ ’ │ — │ ÷ │ │
+ * ├───┴─┬─┴─┬─┴─┬─┴─┬─┴─┬─┴─┬─┴─┬─┴─┬─┴─┬─┴─┬─┴─┬─┴─┬─┴─┬─────┤
+ * │ │ │ │ │ │ │ │ │ │ │ │ ‹ │ › │ ¦ │
+ * ├─────┴┬──┴┬──┴┬──┴┬──┴┬──┴┬──┴┬──┴┬──┴┬──┴┬──┴┬──┴┬──┴─────┤
+ * │ │ │ § │ │ │ │ │ │ │ │ · │ ¨ │ │
+ * ├──────┴─┬─┴─┬─┴─┬─┴─┬─┴─┬─┴─┬─┴─┬─┴─┬─┴─┬─┴─┬─┴─┬─┴────────┤
+ * │ │ │ │ │ │ │ │ │ │ │ … │ │
+ * ├────┬───┴┬──┴─┬─┴───┴───┴───┴───┴───┴──┬┴───┼───┴┬────┬────┤
+ * │ │ │ │ │ │ │ │ │
+ * └────┴────┴────┴────────────────────────┴────┴────┴────┴────┘
+ */
+ "ALGR(EU_TILD)": {
+ "key": "EU_DTIL",
+ "label": "~ (dead)",
+ }
+ "S(ALGR(EU_1))": {
+ "key": "EU_SUP1",
+ "label": "¹",
+ }
+ "S(ALGR(EU_2))": {
+ "key": "EU_SUP2",
+ "label": "²",
+ }
+ "S(ALGR(EU_3))": {
+ "key": "EU_SUP3",
+ "label": "³",
+ }
+ "ALGR(EU_DLR)": {
+ "key": "EU_YEN",
+ "label": "¥",
+ }
+ "S(EU_EURO)": {
+ "key": "EU_CENT",
+ "label": "¢",
+ }
+ "S(EU_DCIR)": {
+ "key": "EU_CARN",
+ "label": "ˇ (dead)",
+ }
+ "S(ALGR(EU_7))": {
+ "key": "EU_MACR",
+ "label": "¯ (dead)",
+ }
+ "S(EU_DLQU)": {
+ "key": "EU_SLQU",
+ "label": "‚",
+ }
+ "S(EU_LDQU)": {
+ "key": "EU_LSQU",
+ "label": "‘",
+ }
+ "S(EU_RDQU)": {
+ "key": "EU_RSQU",
+ "label": "’",
+ }
+ "S(EU_NDSH)": {
+ "key": "EU_MDSH",
+ "label": "—",
+ }
+ "S(EU_MUL)": {
+ "key": "EU_DIV",
+ "label": "÷",
+ }
+ "S(EU_LDAQ)": {
+ "key": "EU_LSAQ",
+ "label": "‹",
+ }
+ "S(EU_RDAQ)": {
+ "key": "EU_RSAQ",
+ "label": "›",
+ }
+ "S(ALGR(EU_BSLS))": {
+ "key": "EU_BRKP",
+ "label": "¦",
+ }
+ "S(ALGR(EU_S))": {
+ "key": "EU_SECT",
+ "label": "§",
+ }
+ "S(ALGR(EU_SCLN))": {
+ "key": "EU_MDDT",
+ "label": "·",
+ }
+ "ALGR(EU_DQUO)": {
+ "key": "EU_DIAE",
+ "label": "¨ (dead)",
+ }
+ "ALGR(EU_QUES)": {
+ "key": "EU_ELLP",
+ "label": "…",
+ }
+ }
+} \ No newline at end of file
diff --git a/data/constants/keycodes/extras/keycodes_farsi_0.0.1.hjson b/data/constants/keycodes/extras/keycodes_farsi_0.0.1.hjson
index d59b6fab26..68d209a5f3 100644
--- a/data/constants/keycodes/extras/keycodes_farsi_0.0.1.hjson
+++ b/data/constants/keycodes/extras/keycodes_farsi_0.0.1.hjson
@@ -527,7 +527,7 @@
"key": "FA_PIPE",
"label": "|",
}
- "ALGR(FA_RA)": {
+ "ALGR(FA_RE)": {
"key": "FA_SUBA",
"label": "ٖ",
}
diff --git a/data/mappings/keyboard_aliases.hjson b/data/mappings/keyboard_aliases.hjson
index 72f6994c09..4fd959c4eb 100644
--- a/data/mappings/keyboard_aliases.hjson
+++ b/data/mappings/keyboard_aliases.hjson
@@ -140,6 +140,9 @@
"custommk/genesis": {
"target": "custommk/genesis/rev1"
},
+ "cxt_studio":{
+ "target":"cxt_studio/12e4"
+ },
"daisy": {
"target": "ktec/daisy"
},
@@ -1515,6 +1518,9 @@
"ymd96": {
"target": "ymdk/ymd96"
},
+ "ymdk/id75": {
+ "target": "ymdk/id75/f103"
+ },
"ymdk_np21": {
"target": "ymdk/np21"
},
diff --git a/docs/features/leader_key.md b/docs/features/leader_key.md
index a36e630a36..9f9086e1ae 100644
--- a/docs/features/leader_key.md
+++ b/docs/features/leader_key.md
@@ -154,6 +154,21 @@ User callback, invoked when the leader sequence ends.
---
+### `bool leader_add_user(uint16_t keycode)` {#api-leader-add-user}
+
+User callback, invoked when a keycode is added to the leader sequence.
+
+#### Arguments {#api-leader-add-user-arguments}
+
+ - `uint16_t keycode`
+ The keycode to added to the leader sequence.
+
+#### Return Value {#api-leader-add-user-return}
+
+`true` to finish the key sequence, `false` to continue.
+
+---
+
### `void leader_start(void)` {#api-leader-start}
Begin the leader sequence, resetting the buffer and timer.
diff --git a/docs/reference_keymap_extras.md b/docs/reference_keymap_extras.md
index f6b4b8faf6..c871773651 100644
--- a/docs/reference_keymap_extras.md
+++ b/docs/reference_keymap_extras.md
@@ -55,6 +55,7 @@ These headers are located in [`quantum/keymap_extras/`](https://github.com/qmk/q
|English (US International) |`keymap_us_international.h` |`sendstring_us_international.h` |
|English (US International, Linux)|`keymap_us_international_linux.h`| |
|Estonian |`keymap_estonian.h` |`sendstring_estonian.h` |
+|EurKEY |`keymap_eurkey.h` | |
|Farsi |`keymap_farsi.h` | |
|Finnish |`keymap_finnish.h` |`sendstring_finnish.h` |
|French |`keymap_french.h` |`sendstring_french.h` |
diff --git a/keyboards/cxt_studio/12e4/config.h b/keyboards/cxt_studio/12e4/config.h
new file mode 100644
index 0000000000..de0fbad7ec
--- /dev/null
+++ b/keyboards/cxt_studio/12e4/config.h
@@ -0,0 +1,6 @@
+// Copyright 2023 Colin Kinloch (@ColinKinloch)
+// SPDX-License-Identifier: GPL-2.0-or-later
+
+#pragma once
+
+#define RGB_MATRIX_TYPING_HEATMAP_SPREAD 9
diff --git a/keyboards/cxt_studio/cxt_studio.c b/keyboards/cxt_studio/12e4/cxt_studio.c
index 2b36905340..03a15e4d48 100644
--- a/keyboards/cxt_studio/cxt_studio.c
+++ b/keyboards/cxt_studio/12e4/cxt_studio.c
@@ -3,8 +3,6 @@
#include "quantum.h"
-static uint8_t anim = 0;
-
#ifdef ENCODER_ENABLE
bool encoder_update_kb(uint8_t index, bool clockwise) {
if (!encoder_update_user(index, clockwise)) {
@@ -21,32 +19,26 @@ bool encoder_update_kb(uint8_t index, bool clockwise) {
break;
case 1: {
if (clockwise) {
- rgblight_increase_hue();
+ rgb_matrix_increase_hue();
} else {
- rgblight_decrease_hue();
+ rgb_matrix_decrease_hue();
}
}
break;
case 2: {
if (clockwise) {
- rgblight_increase_val();
+ rgb_matrix_increase_val();
} else {
- rgblight_decrease_val();
+ rgb_matrix_decrease_val();
}
}
break;
case 3: {
if (clockwise) {
- anim++;
+ rgb_matrix_step();
} else {
- anim--;
+ rgb_matrix_step_reverse();
}
- if (anim >= RGB_MATRIX_EFFECT_MAX) {
- anim = 0;
- } else if (anim < 0) {
- anim = RGB_MATRIX_EFFECT_MAX - 1;
- }
- rgblight_mode(anim);
}
break;
}
diff --git a/keyboards/cxt_studio/keyboard.json b/keyboards/cxt_studio/12e4/keyboard.json
index 7ee7b52d50..b48e75f4ca 100644
--- a/keyboards/cxt_studio/keyboard.json
+++ b/keyboards/cxt_studio/12e4/keyboard.json
@@ -1,6 +1,6 @@
{
"manufacturer": "CXT",
- "keyboard_name": "cxt_studio",
+ "keyboard_name": "cxt_studio 12E4",
"maintainer": "ColinKinloch",
"bootloader": "atmel-dfu",
"diode_direction": "ROW2COL",
diff --git a/keyboards/cxt_studio/keymaps/default/keymap.json b/keyboards/cxt_studio/12e4/keymaps/default/keymap.json
index 9e31833520..b05d3ba179 100644
--- a/keyboards/cxt_studio/keymaps/default/keymap.json
+++ b/keyboards/cxt_studio/12e4/keymaps/default/keymap.json
@@ -1,5 +1,5 @@
{
- "keyboard": "cxt_studio",
+ "keyboard": "cxt_studio/12e4",
"keymap": "default",
"layout": "LAYOUT",
"layers": [
diff --git a/keyboards/cxt_studio/readme.md b/keyboards/cxt_studio/12e4/readme.md
index 6397a3fdfd..760c3544b4 100644
--- a/keyboards/cxt_studio/readme.md
+++ b/keyboards/cxt_studio/12e4/readme.md
@@ -1,20 +1,20 @@
-# cxt_studio
+# cxt_studio/12e4
-![cxt_studio](https://i.imgur.com/AMCTioSh.jpeg)
+![cxt_studio/12e4](https://i.imgur.com/AMCTioSh.jpeg)
3x4 ortho rgb lighting 4 knobs.
* Keyboard Maintainer: [Colin Kinloch](https://github.com/ColinKinloch)
-* Hardware Supported: CXT-Studio
+* Hardware Supported: CXT-Studio/12E4
* Hardware Availability: AliExpress. I think the manufacturer is on Taobao.
Make example for this keyboard (after setting up your build environment):
- make cxt_studio:default
+ make cxt_studio/12e4:default
Flashing example for this keyboard:
- make cxt_studio:default:flash
+ make cxt_studio/12e4:default:flash
See the [build environment setup](https://docs.qmk.fm/#/getting_started_build_tools) and the [make instructions](https://docs.qmk.fm/#/getting_started_make_guide) for more information. Brand new to QMK? Start with our [Complete Newbs Guide](https://docs.qmk.fm/#/newbs).
diff --git a/keyboards/cxt_studio/config.h b/keyboards/cxt_studio/config.h
deleted file mode 100644
index e56e07a254..0000000000
--- a/keyboards/cxt_studio/config.h
+++ /dev/null
@@ -1,22 +0,0 @@
-// Copyright 2023 Colin Kinloch (@ColinKinloch)
-// SPDX-License-Identifier: GPL-2.0-or-later
-
-#pragma once
-
-#define RGB_MATRIX_TYPING_HEATMAP_SPREAD 9
-
-/*
- * Feature disable options
- * These options are also useful to firmware size reduction.
- */
-
-/* disable debug print */
-//#define NO_DEBUG
-
-/* disable print */
-//#define NO_PRINT
-
-/* disable action features */
-//#define NO_ACTION_LAYER
-//#define NO_ACTION_TAPPING
-//#define NO_ACTION_ONESHOT
diff --git a/keyboards/kradoindustries/promenade/keyboard.json b/keyboards/kradoindustries/promenade/keyboard.json
index 86330dbc2e..028ba1b24d 100644
--- a/keyboards/kradoindustries/promenade/keyboard.json
+++ b/keyboards/kradoindustries/promenade/keyboard.json
@@ -73,8 +73,8 @@
{"matrix": [1, 3], "x":3.5, "y":1},
{"matrix": [1, 4], "x":4.5, "y":1},
{"matrix": [1, 5], "x":5.5, "y":1},
- {"matrix": [1, 6], "x":6.5, "y":1, "h":1.5},
- {"matrix": [1, 7], "x":7.5, "y":1, "h":1.5},
+ {"matrix": [1, 6], "x":6.5, "y":1},
+ {"matrix": [1, 7], "x":7.5, "y":1},
{"matrix": [1, 8], "x":8.5, "y":1},
{"matrix": [1, 9], "x":9.5, "y":1},
{"matrix": [1, 10], "x":10.5, "y":1},
@@ -88,6 +88,8 @@
{"matrix": [2, 3], "x":3.5, "y":2},
{"matrix": [2, 4], "x":4.5, "y":2},
{"matrix": [2, 5], "x":5.5, "y":2},
+ {"matrix": [2, 6], "x":6.5, "y":2},
+ {"matrix": [2, 7], "x":7.5, "y":2},
{"matrix": [2, 8], "x":8.5, "y":2},
{"matrix": [2, 9], "x":9.5, "y":2},
{"matrix": [2, 10], "x":10.5, "y":2},
@@ -101,8 +103,8 @@
{"matrix": [3, 3], "x":3.5, "y":3},
{"matrix": [3, 4], "x":4.5, "y":3},
{"matrix": [3, 5], "x":5.5, "y":3},
- {"matrix": [3, 6], "x":6.5, "y":2.5, "h":1.5},
- {"matrix": [3, 7], "x":7.5, "y":2.5, "h":1.5},
+ {"matrix": [3, 6], "x":6.5, "y":3},
+ {"matrix": [3, 7], "x":7.5, "y":3},
{"matrix": [3, 8], "x":8.5, "y":3},
{"matrix": [3, 9], "x":9.5, "y":3},
{"matrix": [3, 10], "x":10.5, "y":3},
diff --git a/keyboards/kradoindustries/promenade/matrix_diagram.md b/keyboards/kradoindustries/promenade/matrix_diagram.md
index 086471b8b9..3c205c9a99 100644
--- a/keyboards/kradoindustries/promenade/matrix_diagram.md
+++ b/keyboards/kradoindustries/promenade/matrix_diagram.md
@@ -5,10 +5,10 @@
│00 │01 │02 │03 │04 │05 │06 │07 │08 │09 │0A │0B │0C │0D │
├─────┼───┼───┼───┼───┼───┼───┼───┼───┼───┼───┼───┼───┼─────┤
│10 │11 │12 │13 │14 │15 │16 │17 │18 │19 │1A │1B │1C │1D │
-├─────┼───┼───┼───┼───┼───┤ │ ├───┼───┼───┼───┼───┼─────┤
-│20 │21 │22 │23 │24 │25 ├───┼───┤28 │29 │2A │2B │2C │2D │
-├─────┼───┼───┼───┼───┼───┤36 │37 ├───┼───┼───┼───┼───┼─────┤
-│30 │31 │32 │33 │34 │35 │ │ │38 │39 │3A │3B │3C │3D │
+├─────┼───┼───┼───┼───┼───├───┼───┼───┼───┼───┼───┼───┼─────┤
+│20 │21 │22 │23 │24 │25 │26 │27 │28 │29 │2A │2B │2C │2D │
+├─────┼───┼───┼───┼───┼───├───┼───┼───┼───┼───┼───┼───┼─────┤
+│30 │31 │32 │33 │34 │35 │36 │37 │38 │39 │3A │3B │3C │3D │
├─────┼───┼───┼───┼───┼───┼───┴───┼───┼───┼───┼───┼───┼─────┤
│40 │41 │42 │43 │44 │45 │46 │48 │49 │4A │4B │4C │4D │
└─────┴───┴───┴───┴───┴───┴───────┴───┴───┴───┴───┴───┴─────┘
diff --git a/keyboards/moky/moky88/config.h b/keyboards/moky/moky88/config.h
index a673a38069..7c102e1a97 100644
--- a/keyboards/moky/moky88/config.h
+++ b/keyboards/moky/moky88/config.h
@@ -15,5 +15,4 @@
/* RGB Driver */
#define AW20216S_CS_PIN_1 D2
#define AW20216S_CS_PIN_2 B8
-#define AW20216S_EN_PIN_1 B9
-#define AW20216S_EN_PIN_2 B9
+#define AW20216S_EN_PIN B9
diff --git a/keyboards/moky/moky88/moky88.c b/keyboards/moky/moky88/moky88.c
index 3cbd6e1468..2de672f94f 100644
--- a/keyboards/moky/moky88/moky88.c
+++ b/keyboards/moky/moky88/moky88.c
@@ -23,97 +23,97 @@ const aw20216s_led_t PROGMEM g_aw20216s_leds[AW20216S_LED_COUNT] = {
* | | G location
* | | | B location
* | | | | */
- {0, CS18_SW2, CS17_SW2, CS16_SW2 }, // 0 Esc
- {0, CS18_SW3, CS17_SW3, CS16_SW3 }, // 1 F1
- {0, CS18_SW4, CS17_SW4, CS16_SW4 }, // 2 F2
- {0, CS18_SW5, CS17_SW5, CS16_SW5 }, // 3 F3
- {0, CS18_SW6, CS17_SW6, CS16_SW6 }, // 4 F4
- {0, CS18_SW7, CS17_SW7, CS16_SW7 }, // 5 F5
- {0, CS18_SW8, CS17_SW8, CS16_SW8 }, // 6 F6
- {0, CS18_SW9, CS17_SW9, CS16_SW9 }, // 7 F7
- {0, CS18_SW10, CS17_SW10, CS16_SW10 }, // 8 F8
- {0, CS18_SW11, CS17_SW11, CS16_SW11 }, // 9 F9
- {0, CS18_SW12, CS17_SW12, CS16_SW12 }, // 10 F10
- {1, CS18_SW1, CS17_SW1, CS16_SW1 }, // 11 F11
- {1, CS18_SW2, CS17_SW2, CS16_SW2 }, // 12 F12
- {1, CS18_SW3, CS17_SW3, CS16_SW3 }, // 13 MUTE
- {1, CS18_SW4, CS17_SW4, CS16_SW4 }, // 14 PSCR
- {1, CS18_SW5, CS17_SW5, CS16_SW5 }, // 15 SCRL
- {1, CS18_SW6, CS17_SW6, CS16_SW6 }, // 16 PAUSE
+ {0, SW2_CS18, SW2_CS17, SW2_CS16 }, // 0 Esc
+ {0, SW3_CS18, SW3_CS17, SW3_CS16 }, // 1 F1
+ {0, SW4_CS18, SW4_CS17, SW4_CS16 }, // 2 F2
+ {0, SW5_CS18, SW5_CS17, SW5_CS16 }, // 3 F3
+ {0, SW6_CS18, SW6_CS17, SW6_CS16 }, // 4 F4
+ {0, SW7_CS18, SW7_CS17, SW7_CS16 }, // 5 F5
+ {0, SW8_CS18, SW8_CS17, SW8_CS16 }, // 6 F6
+ {0, SW9_CS18, SW9_CS17, SW9_CS16 }, // 7 F7
+ {0, SW10_CS18, SW10_CS17, SW10_CS16 }, // 8 F8
+ {0, SW11_CS18, SW11_CS17, SW11_CS16 }, // 9 F9
+ {0, SW12_CS18, SW12_CS17, SW12_CS16 }, // 10 F10
+ {1, SW1_CS18, SW1_CS17, SW1_CS16 }, // 11 F11
+ {1, SW2_CS18, SW2_CS17, SW2_CS16 }, // 12 F12
+ {1, SW3_CS18, SW3_CS17, SW3_CS16 }, // 13 MUTE
+ {1, SW4_CS18, SW4_CS17, SW4_CS16 }, // 14 PSCR
+ {1, SW5_CS18, SW5_CS17, SW5_CS16 }, // 15 SCRL
+ {1, SW6_CS18, SW6_CS17, SW6_CS16 }, // 16 PAUSE
- {0, CS15_SW2, CS14_SW2, CS13_SW2 }, // 17 `~
- {0, CS15_SW3, CS14_SW3, CS13_SW3 }, // 18 1
- {0, CS15_SW4, CS14_SW4, CS13_SW4 }, // 19 2
- {0, CS15_SW5, CS14_SW5, CS13_SW5 }, // 20 3
- {0, CS15_SW6, CS14_SW6, CS13_SW6 }, // 21 4
- {0, CS15_SW7, CS14_SW7, CS13_SW7 }, // 22 5
- {0, CS15_SW8, CS14_SW8, CS13_SW8 }, // 23 6
- {0, CS15_SW9, CS14_SW9, CS13_SW9 }, // 24 7
- {0, CS15_SW10, CS14_SW10, CS13_SW10 }, // 25 8
- {0, CS15_SW11, CS14_SW11, CS13_SW11 }, // 26 9
- {0, CS15_SW12, CS14_SW12, CS13_SW12 }, // 27 0
- {1, CS15_SW1, CS14_SW1, CS13_SW1 }, // 28 -_
- {1, CS15_SW2, CS14_SW2, CS13_SW2 }, // 29 =+
- {1, CS15_SW3, CS14_SW3, CS13_SW3 }, // 30 BSPC
- {1, CS15_SW4, CS14_SW4, CS13_SW4 }, // 31 INS
- {1, CS15_SW5, CS14_SW5, CS13_SW5 }, // 32 HOME
- {1, CS15_SW6, CS14_SW6, CS13_SW6 }, // 33 PGUP
+ {0, SW2_CS15, SW2_CS14, SW2_CS13 }, // 17 `~
+ {0, SW3_CS15, SW3_CS14, SW3_CS13 }, // 18 1
+ {0, SW4_CS15, SW4_CS14, SW4_CS13 }, // 19 2
+ {0, SW5_CS15, SW5_CS14, SW5_CS13 }, // 20 3
+ {0, SW6_CS15, SW6_CS14, SW6_CS13 }, // 21 4
+ {0, SW7_CS15, SW7_CS14, SW7_CS13 }, // 22 5
+ {0, SW8_CS15, SW8_CS14, SW8_CS13 }, // 23 6
+ {0, SW9_CS15, SW9_CS14, SW9_CS13 }, // 24 7
+ {0, SW10_CS15, SW10_CS14, SW10_CS13 }, // 25 8
+ {0, SW11_CS15, SW11_CS14, SW11_CS13 }, // 26 9
+ {0, SW12_CS15, SW12_CS14, SW12_CS13 }, // 27 0
+ {1, SW1_CS15, SW1_CS14, SW1_CS13 }, // 28 -_
+ {1, SW2_CS15, SW2_CS14, SW2_CS13 }, // 29 =+
+ {1, SW3_CS15, SW3_CS14, SW3_CS13 }, // 30 BSPC
+ {1, SW4_CS15, SW4_CS14, SW4_CS13 }, // 31 INS
+ {1, SW5_CS15, SW5_CS14, SW5_CS13 }, // 32 HOME
+ {1, SW6_CS15, SW6_CS14, SW6_CS13 }, // 33 PGUP
- {0, CS12_SW2, CS11_SW2, CS10_SW2 }, // 34 Tab
- {0, CS12_SW3, CS11_SW3, CS10_SW3 }, // 35 Q
- {0, CS12_SW4, CS11_SW4, CS10_SW4 }, // 36 W
- {0, CS12_SW5, CS11_SW5, CS10_SW5 }, // 37 E
- {0, CS12_SW6, CS11_SW6, CS10_SW6 }, // 38 R
- {0, CS12_SW7, CS11_SW7, CS10_SW7 }, // 39 T
- {0, CS12_SW8, CS11_SW8, CS10_SW8 }, // 40 Y
- {0, CS12_SW9, CS11_SW9, CS10_SW9 }, // 41 U
- {0, CS12_SW10, CS11_SW10, CS10_SW10 }, // 42 I
- {0, CS12_SW11, CS11_SW11, CS10_SW11 }, // 43 O
- {0, CS12_SW12, CS11_SW12, CS10_SW12 }, // 44 P
- {1, CS12_SW1, CS11_SW1, CS10_SW1 }, // 45 [{
- {1, CS12_SW2, CS11_SW2, CS10_SW2 }, // 48 ]}
- {1, CS12_SW3, CS11_SW3, CS10_SW3 }, // 47 \|
- {1, CS12_SW4, CS11_SW4, CS10_SW4 }, // 48 Del
- {1, CS12_SW5, CS11_SW5, CS10_SW5 }, // 49 End
- {1, CS12_SW6, CS11_SW6, CS10_SW6 }, // 50 PGDN
+ {0, SW2_CS12, SW2_CS11, SW2_CS10 }, // 34 Tab
+ {0, SW3_CS12, SW3_CS11, SW3_CS10 }, // 35 Q
+ {0, SW4_CS12, SW4_CS11, SW4_CS10 }, // 36 W
+ {0, SW5_CS12, SW5_CS11, SW5_CS10 }, // 37 E
+ {0, SW6_CS12, SW6_CS11, SW6_CS10 }, // 38 R
+ {0, SW7_CS12, SW7_CS11, SW7_CS10 }, // 39 T
+ {0, SW8_CS12, SW8_CS11, SW8_CS10 }, // 40 Y
+ {0, SW9_CS12, SW9_CS11, SW9_CS10 }, // 41 U
+ {0, SW10_CS12, SW10_CS11, SW10_CS10 }, // 42 I
+ {0, SW11_CS12, SW11_CS11, SW11_CS10 }, // 43 O
+ {0, SW12_CS12, SW12_CS11, SW12_CS10 }, // 44 P
+ {1, SW1_CS12, SW1_CS11, SW1_CS10 }, // 45 [{
+ {1, SW2_CS12, SW2_CS11, SW2_CS10 }, // 48 ]}
+ {1, SW3_CS12, SW3_CS11, SW3_CS10 }, // 47 \|
+ {1, SW4_CS12, SW4_CS11, SW4_CS10 }, // 48 Del
+ {1, SW5_CS12, SW5_CS11, SW5_CS10 }, // 49 End
+ {1, SW6_CS12, SW6_CS11, SW6_CS10 }, // 50 PGDN
- {0, CS1_SW2, CS2_SW2, CS3_SW2 }, // 51 Caps
- {0, CS1_SW3, CS2_SW3, CS3_SW3 }, // 52 A
- {0, CS1_SW4, CS2_SW4, CS3_SW4 }, // 33 S
- {0, CS1_SW5, CS2_SW5, CS3_SW5 }, // 54 D
- {0, CS1_SW6, CS2_SW6, CS3_SW6 }, // 55 F
- {0, CS1_SW7, CS2_SW7, CS3_SW7 }, // 56 G
- {0, CS1_SW8, CS2_SW8, CS3_SW8 }, // 57 H
- {0, CS1_SW9, CS2_SW9, CS3_SW9 }, // 58 J
- {0, CS1_SW10, CS2_SW10, CS3_SW10 }, // 59 K
- {0, CS1_SW11, CS2_SW11, CS3_SW11 }, // 60 L
- {0, CS1_SW12, CS2_SW12, CS3_SW12 }, // 61 ;:
- {1, CS1_SW1, CS2_SW1, CS3_SW1 }, // 62 '
- {1, CS1_SW3, CS2_SW3, CS3_SW3 }, // 63 Enter
+ {0, SW2_CS1, SW2_CS2, SW2_CS3 }, // 51 Caps
+ {0, SW3_CS1, SW3_CS2, SW3_CS3 }, // 52 A
+ {0, SW4_CS1, SW4_CS2, SW4_CS3 }, // 33 S
+ {0, SW5_CS1, SW5_CS2, SW5_CS3 }, // 54 D
+ {0, SW6_CS1, SW6_CS2, SW6_CS3 }, // 55 F
+ {0, SW7_CS1, SW7_CS2, SW7_CS3 }, // 56 G
+ {0, SW8_CS1, SW8_CS2, SW8_CS3 }, // 57 H
+ {0, SW9_CS1, SW9_CS2, SW9_CS3 }, // 58 J
+ {0, SW10_CS1, SW10_CS2, SW10_CS3 }, // 59 K
+ {0, SW11_CS1, SW11_CS2, SW11_CS3 }, // 60 L
+ {0, SW12_CS1, SW12_CS2, SW12_CS3 }, // 61 ;:
+ {1, SW1_CS1, SW1_CS2, SW1_CS3 }, // 62 '
+ {1, SW3_CS1, SW3_CS2, SW3_CS3 }, // 63 Enter
- {0, CS4_SW2, CS5_SW2, CS6_SW2 }, // 64 Shift
- {0, CS4_SW4, CS5_SW4, CS6_SW4 }, // 65 Z
- {0, CS4_SW5, CS5_SW5, CS6_SW5 }, // 66 X
- {0, CS4_SW6, CS5_SW6, CS6_SW6 }, // 67 C
- {0, CS4_SW7, CS5_SW7, CS6_SW7 }, // 68 V
- {0, CS4_SW8, CS5_SW8, CS6_SW8 }, // 69 B
- {0, CS4_SW9, CS5_SW9, CS6_SW9 }, // 70 N
- {0, CS4_SW10, CS5_SW10, CS6_SW10 }, // 71 M
- {0, CS4_SW11, CS5_SW11, CS6_SW11 }, // 72 ,<
- {0, CS4_SW12, CS5_SW12, CS6_SW12 }, // 73 .>
- {1, CS4_SW1, CS5_SW1, CS6_SW1 }, // 74 ?
- {1, CS4_SW3, CS5_SW3, CS6_SW3 }, // 75 Shift
- {1, CS4_SW5, CS5_SW5, CS6_SW5 }, // 76 Up
+ {0, SW2_CS4, SW2_CS5, SW2_CS6 }, // 64 Shift
+ {0, SW4_CS4, SW4_CS5, SW4_CS6 }, // 65 Z
+ {0, SW5_CS4, SW5_CS5, SW5_CS6 }, // 66 X
+ {0, SW6_CS4, SW6_CS5, SW6_CS6 }, // 67 C
+ {0, SW7_CS4, SW7_CS5, SW7_CS6 }, // 68 V
+ {0, SW8_CS4, SW8_CS5, SW8_CS6 }, // 69 B
+ {0, SW9_CS4, SW9_CS5, SW9_CS6 }, // 70 N
+ {0, SW10_CS4, SW10_CS5, SW10_CS6 }, // 71 M
+ {0, SW11_CS4, SW11_CS5, SW11_CS6 }, // 72 ,<
+ {0, SW12_CS4, SW12_CS5, SW12_CS6 }, // 73 .>
+ {1, SW1_CS4, SW1_CS5, SW1_CS6 }, // 74 ?
+ {1, SW3_CS4, SW3_CS5, SW3_CS6 }, // 75 Shift
+ {1, SW5_CS4, SW5_CS5, SW5_CS6 }, // 76 Up
- {0, CS7_SW2, CS8_SW2, CS9_SW2 }, // 77 Ctrl_L
- {0, CS7_SW3, CS8_SW3, CS9_SW3 }, // 78 Win_L
- {0, CS7_SW4, CS8_SW4, CS9_SW4 }, // 79 ALT_L
- {0, CS7_SW8, CS8_SW8, CS9_SW8 }, // 80 SPACE
- {0, CS7_SW12, CS8_SW12, CS9_SW12 }, // 81 ALT_L
- {1, CS7_SW1, CS8_SW1, CS9_SW1 }, // 82 Win_L
- {1, CS7_SW2, CS8_SW2, CS9_SW2 }, // 83 Fn
- {1, CS7_SW3, CS8_SW3, CS9_SW3 }, // 84 Ctrl_L
- {1, CS7_SW4, CS8_SW4, CS9_SW4 }, // 85 Left
- {1, CS7_SW5, CS8_SW5, CS9_SW5 }, // 86 Down
- {1, CS7_SW6, CS8_SW6, CS9_SW6 }, // 87 Right
+ {0, SW2_CS7, SW2_CS8, SW2_CS9 }, // 77 Ctrl_L
+ {0, SW3_CS7, SW3_CS8, SW3_CS9 }, // 78 Win_L
+ {0, SW4_CS7, SW4_CS8, SW4_CS9 }, // 79 ALT_L
+ {0, SW8_CS7, SW8_CS8, SW8_CS9 }, // 80 SPACE
+ {0, SW12_CS7, SW12_CS8, SW12_CS9 }, // 81 ALT_L
+ {1, SW1_CS7, SW1_CS8, SW1_CS9 }, // 82 Win_L
+ {1, SW2_CS7, SW2_CS8, SW2_CS9 }, // 83 Fn
+ {1, SW3_CS7, SW3_CS8, SW3_CS9 }, // 84 Ctrl_L
+ {1, SW4_CS7, SW4_CS8, SW4_CS9 }, // 85 Left
+ {1, SW5_CS7, SW5_CS8, SW5_CS9 }, // 86 Down
+ {1, SW6_CS7, SW6_CS8, SW6_CS9 }, // 87 Right
};
diff --git a/keyboards/silakka54/config.h b/keyboards/silakka54/config.h
new file mode 100644
index 0000000000..220b85cd08
--- /dev/null
+++ b/keyboards/silakka54/config.h
@@ -0,0 +1,25 @@
+/* Copyright 2024 Juho T. (@Squalius-cephalus)
+ *
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ */
+
+#pragma once
+
+#define SERIAL_USART_FULL_DUPLEX
+#define SERIAL_USART_TX_PIN GP0
+#define SERIAL_USART_RX_PIN GP1
+
+#define RP2040_BOOTLOADER_DOUBLE_TAP_RESET
+#define RP2040_BOOTLOADER_DOUBLE_TAP_RESET_TIMEOUT 200U
+#define RP2040_BOOTLOADER_DOUBLE_TAP_RESET_LED GP17
diff --git a/keyboards/silakka54/keyboard.json b/keyboards/silakka54/keyboard.json
new file mode 100644
index 0000000000..e1ad9aac9e
--- /dev/null
+++ b/keyboards/silakka54/keyboard.json
@@ -0,0 +1,102 @@
+{
+ "manufacturer": "Squalius-cephalus",
+ "keyboard_name": "silakka54",
+ "maintainer": "Squalius-cephalus",
+ "bootloader": "rp2040",
+ "diode_direction": "COL2ROW",
+ "features": {
+ "bootmagic": true,
+ "extrakey": true,
+ "mousekey": true,
+ "nkro": true
+ },
+ "split": {
+ "enabled": true,
+ "serial": {
+ "driver": "vendor"
+ }
+ },
+ "matrix_pins": {
+ "cols": ["GP7", "GP8", "GP9", "GP10", "GP11", "GP12"],
+ "rows": ["GP2", "GP3", "GP4", "GP5","GP6"]
+ },
+ "processor": "RP2040",
+ "url": "https://github.com/Squalius-cephalus/silakka54",
+ "usb": {
+ "device_version": "1.0.0",
+ "pid": "0x1212",
+ "vid": "0xFEED"
+ },
+ "layouts": {
+ "LAYOUT": {
+ "layout": [
+ {"matrix": [0, 0], "x": 0, "y": 0},
+ {"matrix": [0, 1], "x": 1, "y": 0},
+ {"matrix": [0, 2], "x": 2, "y": 0},
+ {"matrix": [0, 3], "x": 3, "y": 0},
+ {"matrix": [0, 4], "x": 4, "y": 0},
+ {"matrix": [0, 5], "x": 5, "y": 0},
+
+ {"matrix": [5, 5], "x": 0, "y": 5},
+ {"matrix": [5, 4], "x": 1, "y": 5},
+ {"matrix": [5, 3], "x": 2, "y": 5},
+ {"matrix": [5, 2], "x": 3, "y": 5},
+ {"matrix": [5, 1], "x": 4, "y": 5},
+ {"matrix": [5, 0], "x": 5, "y": 5},
+
+
+ {"matrix": [1, 0], "x": 0, "y": 1},
+ {"matrix": [1, 1], "x": 1, "y": 1},
+ {"matrix": [1, 2], "x": 2, "y": 1},
+ {"matrix": [1, 3], "x": 3, "y": 1},
+ {"matrix": [1, 4], "x": 4, "y": 1},
+ {"matrix": [1, 5], "x": 5, "y": 1},
+
+ {"matrix": [6, 5], "x": 0, "y": 6},
+ {"matrix": [6, 4], "x": 1, "y": 6},
+ {"matrix": [6, 3], "x": 2, "y": 6},
+ {"matrix": [6, 2], "x": 3, "y": 6},
+ {"matrix": [6, 1], "x": 4, "y": 6},
+ {"matrix": [6, 0], "x": 5, "y": 6},
+
+ {"matrix": [2, 0], "x": 0, "y": 2},
+ {"matrix": [2, 1], "x": 1, "y": 2},
+ {"matrix": [2, 2], "x": 2, "y": 2},
+ {"matrix": [2, 3], "x": 3, "y": 2},
+ {"matrix": [2, 4], "x": 4, "y": 2},
+ {"matrix": [2, 5], "x": 5, "y": 2},
+
+ {"matrix": [7, 5], "x": 0, "y": 7},
+ {"matrix": [7, 4], "x": 1, "y": 7},
+ {"matrix": [7, 3], "x": 2, "y": 7},
+ {"matrix": [7, 2], "x": 3, "y": 7},
+ {"matrix": [7, 1], "x": 4, "y": 7},
+ {"matrix": [7, 0], "x": 5, "y": 7},
+
+ {"matrix": [3, 0], "x": 0, "y": 3},
+ {"matrix": [3, 1], "x": 1, "y": 3},
+ {"matrix": [3, 2], "x": 2, "y": 3},
+ {"matrix": [3, 3], "x": 3, "y": 3},
+ {"matrix": [3, 4], "x": 4, "y": 3},
+ {"matrix": [3, 5], "x": 5, "y": 3},
+
+ {"matrix": [8, 5], "x": 0, "y": 9},
+ {"matrix": [8, 4], "x": 1, "y": 9},
+ {"matrix": [8, 3], "x": 2, "y": 9},
+ {"matrix": [8, 2], "x": 3, "y": 9},
+ {"matrix": [8, 1], "x": 4, "y": 9},
+ {"matrix": [8, 0], "x": 5, "y": 9},
+
+ {"matrix": [4, 3], "x": 3, "y": 4},
+ {"matrix": [4, 4], "x": 4, "y": 4},
+ {"matrix": [4, 5], "x": 5, "y": 4},
+
+ {"matrix": [9, 5], "x": 3, "y": 9},
+ {"matrix": [9, 4], "x": 4, "y": 9},
+ {"matrix": [9, 3], "x": 5, "y": 9}
+
+
+ ]
+ }
+ }
+}
diff --git a/keyboards/silakka54/keymaps/default/keymap.c b/keyboards/silakka54/keymaps/default/keymap.c
new file mode 100644
index 0000000000..aa5e64efa3
--- /dev/null
+++ b/keyboards/silakka54/keymaps/default/keymap.c
@@ -0,0 +1,22 @@
+// Copyright 2023 QMK
+// SPDX-License-Identifier: GPL-2.0-or-later
+
+#include QMK_KEYBOARD_H
+
+const uint16_t PROGMEM keymaps[][MATRIX_ROWS][MATRIX_COLS] = {
+
+ [0] = LAYOUT(
+ KC_ESC, KC_1, KC_2, KC_3, KC_4, KC_5, KC_6, KC_7, KC_8, KC_9, KC_0, KC_MINS,
+ KC_TAB, KC_Q, KC_W, KC_E, KC_R, KC_T, KC_Y, KC_U, KC_I, KC_O, KC_P, KC_BSPC,
+ KC_LCTL, KC_A, KC_S, KC_D, KC_F, KC_G, KC_H, KC_J, KC_K, KC_L, KC_SCLN, KC_QUOT,
+ KC_LSFT, KC_Z, KC_X, KC_C, KC_V, KC_B, KC_N, KC_M, KC_COMM, KC_DOT, KC_SLSH, KC_RSFT,
+ KC_LGUI, MO(1), KC_SPC, KC_ENT, KC_RCTL, KC_RALT
+ ),
+ [1] = LAYOUT(
+ KC_GRV, KC_F1, KC_F2, KC_F3, KC_F4, KC_F5, KC_F6, KC_F7, KC_F8, KC_F9, KC_F10, KC_F11,
+ KC_TRNS, KC_TRNS, KC_TRNS, KC_TRNS, KC_TRNS, KC_TRNS, KC_PGUP, KC_PGDN, KC_HOME, KC_END, KC_DEL, KC_F12,
+ KC_TRNS, KC_TRNS, KC_TRNS, KC_TRNS, KC_TRNS, KC_TRNS, KC_LEFT, KC_DOWN, KC_UP, KC_RGHT, KC_LBRC, KC_RBRC,
+ KC_TRNS, KC_TRNS, KC_TRNS, KC_TRNS, KC_TRNS, KC_TRNS, KC_TRNS, KC_TRNS, KC_TRNS, KC_TRNS, KC_TRNS, KC_TRNS,
+ KC_TRNS, KC_TRNS, KC_TRNS, KC_TRNS, KC_TRNS, KC_TRNS
+ )
+};
diff --git a/keyboards/silakka54/readme.md b/keyboards/silakka54/readme.md
new file mode 100644
index 0000000000..08a38aa473
--- /dev/null
+++ b/keyboards/silakka54/readme.md
@@ -0,0 +1,26 @@
+# Silakka54
+
+![Silakka54](https://i.imgur.com/JrsS0kY.png)
+
+Silakka54 is a RP2040 Zero based 54-key column staggered split keyboard. PCB uses hotswap sockets. Design is inspired from REVIUNG41 and Corne keyboards.
+
+* Keyboard Maintainer: [Squalius-cephalus](https://github.com/Squalius-cephalus)
+* Hardware Supported: Silakka54 PCB
+* Hardware Availability: https://github.com/Squalius-cephalus/silakka54
+
+Make example for this keyboard (after setting up your build environment):
+
+ make silakka54:default
+
+Flashing example for this keyboard:
+
+ make silakka54:default:flash
+
+See the [build environment setup](https://docs.qmk.fm/#/getting_started_build_tools) and the [make instructions](https://docs.qmk.fm/#/getting_started_make_guide) for more information. Brand new to QMK? Start with our [Complete Newbs Guide](https://docs.qmk.fm/#/newbs).
+
+## Bootloader
+
+Enter the bootloader in 2 ways:
+
+* **Physical boot button**: Hold BOOT button down and connect MCU to the PC
+* **Keycode in layout**: Press the key mapped to `QK_BOOT` if it is available
diff --git a/keyboards/skyloong/gk61/pro/config.h b/keyboards/skyloong/gk61/pro/config.h
index db02496f8b..aeea36e0bc 100644
--- a/keyboards/skyloong/gk61/pro/config.h
+++ b/keyboards/skyloong/gk61/pro/config.h
@@ -7,6 +7,3 @@
#define IS31FL3743A_SDB_PIN C1
#define CAPS_LOCK_INDEX 28
-#define WIN_MOD_INDEX 16
-#define MAC_MOD_INDEX 17
-#define WIN_LOCK_INDEX 54
diff --git a/keyboards/skyloong/gk61/pro/pro.c b/keyboards/skyloong/gk61/pro/pro.c
index 2299977e0e..11411ba2b1 100644
--- a/keyboards/skyloong/gk61/pro/pro.c
+++ b/keyboards/skyloong/gk61/pro/pro.c
@@ -1,11 +1,8 @@
// Copyright 2023 linlin012 (@linlin012)
// SPDX-License-Identifier: GPL-2.0-or-later
#include "quantum.h"
-int FN_WIN = 0;
-int FN_MAC = 0;
-int L_WIN = 0;
-int L_MAC = 0;
+#if defined(RGB_MATRIX_ENABLE)
const is31fl3743a_led_t PROGMEM g_is31fl3743a_leds[IS31FL3743A_LED_COUNT] = {
/* Refer to IS31 manual for these locations
* driver
@@ -83,7 +80,32 @@ const is31fl3743a_led_t PROGMEM g_is31fl3743a_leds[IS31FL3743A_LED_COUNT] = {
{0, SW10_CS13, SW10_CS14, SW10_CS15}
};
-#if defined(RGB_MATRIX_ENABLE) /*&& defined(CAPS_LOCK_INDEX)*/
+bool rgb_matrix_indicators_advanced_kb(uint8_t led_min, uint8_t led_max) {
+ if (!rgb_matrix_indicators_advanced_user(led_min, led_max)) {
+ return false;
+ }
+
+ if (host_keyboard_led_state().caps_lock) {
+ RGB_MATRIX_INDICATOR_SET_COLOR(CAPS_LOCK_INDEX, 255, 255, 255);
+ } else {
+ if (!rgb_matrix_get_flags()) {
+ RGB_MATRIX_INDICATOR_SET_COLOR(CAPS_LOCK_INDEX, 0, 0, 0);
+ }
+ }
+
+ return false;
+}
+
+void suspend_power_down_kb(void) {
+ gpio_write_pin_low(IS31FL3743A_SDB_PIN);
+ suspend_power_down_user();
+}
+
+void suspend_wakeup_init_kb(void) {
+ gpio_write_pin_high(IS31FL3743A_SDB_PIN);
+ suspend_wakeup_init_user();
+}
+#endif
bool process_record_kb(uint16_t keycode, keyrecord_t *record) {
if (!process_record_user(keycode, record)) {
@@ -105,124 +127,9 @@ bool process_record_kb(uint16_t keycode, keyrecord_t *record) {
}
return false;
# endif
- case TO(0):
- if (record->event.pressed) {
- L_WIN = 1;
- set_single_persistent_default_layer(0); // Save default layer 0 to eeprom
- } else {
- L_WIN = 0;
- }
- return true; // continue all further processing of this key
-
- case MO(2):
- if (record->event.pressed) {
- FN_WIN = 1;
- } else {
- FN_WIN = 0;
- }
- return true; // continue all further processing of this key
-
- case TO(1):
- if (record->event.pressed) {
- L_MAC = 1;
- set_single_persistent_default_layer(1); //Save default layer 1 to eeprom
- } else {
- L_MAC = 0;
- }
- return true; // continue all further processing of this key
-
- case MO(3):
- if (record->event.pressed) {
- FN_MAC = 1;
- } else {
- FN_MAC = 0;
- }
- return true; // continue all further processing of this key
- default:
- return true;
- }
-
-}
-
-bool rgb_matrix_indicators_advanced_kb(uint8_t led_min, uint8_t led_max) {
- if (!rgb_matrix_indicators_advanced_user(led_min, led_max)) {
- return false;
- }
-
- if (host_keyboard_led_state().caps_lock) {
- RGB_MATRIX_INDICATOR_SET_COLOR(CAPS_LOCK_INDEX, 255, 255, 255);
- } else {
- if (!rgb_matrix_get_flags()) {
- RGB_MATRIX_INDICATOR_SET_COLOR(CAPS_LOCK_INDEX, 0, 0, 0);
- }
- }
-
- switch (get_highest_layer(layer_state)) {
- case 0:{
- if (L_WIN) {
- RGB_MATRIX_INDICATOR_SET_COLOR(WIN_MOD_INDEX, 255, 255, 255);
- if (!rgb_matrix_get_flags()) {
- RGB_MATRIX_INDICATOR_SET_COLOR(MAC_MOD_INDEX, 0, 0, 0);
- }
- }else{
- if (!rgb_matrix_get_flags()) {
- RGB_MATRIX_INDICATOR_SET_COLOR(WIN_MOD_INDEX, 0, 0, 0);
- }
- }
- } break;
-
- case 1:{
- if (L_MAC) {
- RGB_MATRIX_INDICATOR_SET_COLOR(MAC_MOD_INDEX, 255, 255, 255);
- if (!rgb_matrix_get_flags()) {
- RGB_MATRIX_INDICATOR_SET_COLOR(WIN_MOD_INDEX, 0, 0, 0);
- }
- }else{
- if (!rgb_matrix_get_flags()) {
- RGB_MATRIX_INDICATOR_SET_COLOR(MAC_MOD_INDEX, 0, 0, 0);
- }
- }
- } break;
-
-
- case 2:{
- RGB_MATRIX_INDICATOR_SET_COLOR(WIN_MOD_INDEX, 255, 255, 255);
- if (!rgb_matrix_get_flags()) {
- RGB_MATRIX_INDICATOR_SET_COLOR(MAC_MOD_INDEX, 0, 0, 0);
- }
- } break;
-
- case 3:{
- RGB_MATRIX_INDICATOR_SET_COLOR(MAC_MOD_INDEX, 255, 255, 255);
- if (!rgb_matrix_get_flags()) {
- RGB_MATRIX_INDICATOR_SET_COLOR(WIN_MOD_INDEX, 0, 0, 0);
- }
- } break;
-
- default:{
- if (!rgb_matrix_get_flags()) {
- RGB_MATRIX_INDICATOR_SET_COLOR(WIN_MOD_INDEX, 0, 0, 0);
- RGB_MATRIX_INDICATOR_SET_COLOR(MAC_MOD_INDEX, 0, 0, 0);
- }
- }
}
- return false;
-}
-
-#endif
-void suspend_power_down_kb() {
-# ifdef RGB_MATRIX_ENABLE
- gpio_write_pin_low(IS31FL3743A_SDB_PIN);
-# endif
- suspend_power_down_user();
-}
-
-void suspend_wakeup_init_kb() {
-# ifdef RGB_MATRIX_ENABLE
- gpio_write_pin_high(IS31FL3743A_SDB_PIN);
-# endif
- suspend_wakeup_init_user();
+ return true;
}
void board_init(void) {
diff --git a/keyboards/skyloong/gk61/pro_48/config.h b/keyboards/skyloong/gk61/pro_48/config.h
index 5b4976e2da..7e45ac8354 100644
--- a/keyboards/skyloong/gk61/pro_48/config.h
+++ b/keyboards/skyloong/gk61/pro_48/config.h
@@ -7,7 +7,3 @@
#define IS31FL3743A_SDB_PIN A4
#define CAPS_LOCK_INDEX 28
-#define WIN_MOD_INDEX 16
-#define MAC_MOD_INDEX 17
-
-#define g_suspend_state rgb_matrix_get_suspend_state()
diff --git a/keyboards/skyloong/gk61/pro_48/pro_48.c b/keyboards/skyloong/gk61/pro_48/pro_48.c
index 6da76a1767..11411ba2b1 100644
--- a/keyboards/skyloong/gk61/pro_48/pro_48.c
+++ b/keyboards/skyloong/gk61/pro_48/pro_48.c
@@ -1,12 +1,8 @@
// Copyright 2023 linlin012 (@linlin012)
// SPDX-License-Identifier: GPL-2.0-or-later
#include "quantum.h"
-_Bool FN_WIN = 0;
-_Bool FN_MAC = 0;
-_Bool L_WIN = 0;
-_Bool L_MAC = 0;
-#if defined(RGB_MATRIX_ENABLE) /*&& defined(CAPS_LOCK_INDEX)*/
+#if defined(RGB_MATRIX_ENABLE)
const is31fl3743a_led_t PROGMEM g_is31fl3743a_leds[IS31FL3743A_LED_COUNT] = {
/* Refer to IS31 manual for these locations
* driver
@@ -97,57 +93,9 @@ bool rgb_matrix_indicators_advanced_kb(uint8_t led_min, uint8_t led_max) {
}
}
- switch (get_highest_layer(layer_state)) {
- case 2:{
- RGB_MATRIX_INDICATOR_SET_COLOR(WIN_MOD_INDEX, 255, 255, 255);
- if (!rgb_matrix_get_flags()) {
- RGB_MATRIX_INDICATOR_SET_COLOR(MAC_MOD_INDEX, 0, 0, 0);
- }
- } break;
- case 3:{
- RGB_MATRIX_INDICATOR_SET_COLOR(MAC_MOD_INDEX, 255, 255, 255);
- if (!rgb_matrix_get_flags()) {
- RGB_MATRIX_INDICATOR_SET_COLOR(WIN_MOD_INDEX, 0, 0, 0);
- }
- } break;
-
- case 0:{
- if (L_WIN) {
- RGB_MATRIX_INDICATOR_SET_COLOR(WIN_MOD_INDEX, 255, 255, 255);
- if (!rgb_matrix_get_flags()) {
- RGB_MATRIX_INDICATOR_SET_COLOR(MAC_MOD_INDEX, 0, 0, 0);
- }
- }else{
- if (!rgb_matrix_get_flags()) {
- RGB_MATRIX_INDICATOR_SET_COLOR(WIN_MOD_INDEX, 0, 0, 0);
- }
- }
- } break;
-
- case 1:{
- if (L_MAC) {
- RGB_MATRIX_INDICATOR_SET_COLOR(MAC_MOD_INDEX, 255, 255, 255);
- if (!rgb_matrix_get_flags()) {
- RGB_MATRIX_INDICATOR_SET_COLOR(WIN_MOD_INDEX, 0, 0, 0);
- }
- }else{
- if (!rgb_matrix_get_flags()) {
- RGB_MATRIX_INDICATOR_SET_COLOR(MAC_MOD_INDEX, 0, 0, 0);
- }
- }
- } break;
-
- default:{
- if (!rgb_matrix_get_flags()) {
- RGB_MATRIX_INDICATOR_SET_COLOR(WIN_MOD_INDEX, 0, 0, 0);
- RGB_MATRIX_INDICATOR_SET_COLOR(MAC_MOD_INDEX, 0, 0, 0);
- }
- }
- }
return false;
}
-
void suspend_power_down_kb(void) {
gpio_write_pin_low(IS31FL3743A_SDB_PIN);
suspend_power_down_user();
@@ -177,44 +125,11 @@ bool process_record_kb(uint16_t keycode, keyrecord_t *record) {
} break;
}
}
- return false;
+ return false;
# endif
- case TO(0):
- if (record->event.pressed) {
- L_WIN = 1;
- set_single_persistent_default_layer(0); // Save default layer 0 to eeprom
- } else {
- L_WIN = 0;
- }
- return true; // continue all further processing of this key
-
- case MO(2):
- if (record->event.pressed) {
- FN_WIN = 1;
- } else {
- FN_WIN = 0;
- }
- return true; // continue all further processing of this key
-
- case TO(1):
- if (record->event.pressed) {
- L_MAC = 1;
- set_single_persistent_default_layer(1); //Save default layer 1 to eeprom
- } else {
- L_MAC = 0;
- }
- return true; // continue all further processing of this key
-
- case MO(3):
- if (record->event.pressed) {
- FN_MAC = 1;
- } else {
- FN_MAC = 0;
- }
- return true; // continue all further processing of this key
- default:
- return true;
}
+
+ return true;
}
void board_init(void) {
diff --git a/keyboards/ymdk/id75/board.h b/keyboards/ymdk/id75/f103/board.h
index 49270b36a0..49270b36a0 100644
--- a/keyboards/ymdk/id75/board.h
+++ b/keyboards/ymdk/id75/f103/board.h
diff --git a/keyboards/ymdk/id75/config.h b/keyboards/ymdk/id75/f103/config.h
index cb5ac78304..cb5ac78304 100644
--- a/keyboards/ymdk/id75/config.h
+++ b/keyboards/ymdk/id75/f103/config.h
diff --git a/keyboards/ymdk/id75/halconf.h b/keyboards/ymdk/id75/f103/halconf.h
index 612ce4fc4a..612ce4fc4a 100644
--- a/keyboards/ymdk/id75/halconf.h
+++ b/keyboards/ymdk/id75/f103/halconf.h
diff --git a/keyboards/ymdk/id75/f103/keyboard.json b/keyboards/ymdk/id75/f103/keyboard.json
new file mode 100644
index 0000000000..5b1974b3f2
--- /dev/null
+++ b/keyboards/ymdk/id75/f103/keyboard.json
@@ -0,0 +1,13 @@
+{
+ "manufacturer": "YMDK",
+ "bootloader": "uf2boot",
+ "matrix_pins": {
+ "cols": ["A10", "A9", "A8", "B15", "B14", "B13", "B12", "A5", "A6", "A4", "A3", "A2", "A1", "A0", "A15"],
+ "rows": ["B2", "B1", "B0", "A7", "B10"]
+ },
+ "processor": "STM32F103",
+ "ws2812": {
+ "driver": "pwm",
+ "pin": "B9"
+ }
+}
diff --git a/keyboards/ymdk/id75/mcuconf.h b/keyboards/ymdk/id75/f103/mcuconf.h
index 0d3de3dad5..0d3de3dad5 100644
--- a/keyboards/ymdk/id75/mcuconf.h
+++ b/keyboards/ymdk/id75/f103/mcuconf.h
diff --git a/keyboards/ymdk/id75/rules.mk b/keyboards/ymdk/id75/f103/rules.mk
index dbee20ab05..dbee20ab05 100644
--- a/keyboards/ymdk/id75/rules.mk
+++ b/keyboards/ymdk/id75/f103/rules.mk
diff --git a/keyboards/ymdk/id75/keyboard.json b/keyboards/ymdk/id75/info.json
index db0c108542..bbe4d1c73e 100644
--- a/keyboards/ymdk/id75/keyboard.json
+++ b/keyboards/ymdk/id75/info.json
@@ -1,8 +1,6 @@
{
- "manufacturer": "YMDK",
"keyboard_name": "Idobao x YMDK ID75",
"maintainer": "qmk",
- "bootloader": "uf2boot",
"diode_direction": "ROW2COL",
"features": {
"bootmagic": true,
@@ -11,152 +9,143 @@
"nkro": true,
"rgb_matrix": true
},
- "matrix_pins": {
- "cols": ["A10", "A9", "A8", "B15", "B14", "B13", "B12", "A5", "A6", "A4", "A3", "A2", "A1", "A0", "A15"],
- "rows": ["B2", "B1", "B0", "A7", "B10"]
- },
- "processor": "STM32F103",
- "ws2812": {
- "driver": "pwm",
- "pin": "B9"
- },
"rgb_matrix": {
"animations": {
"alphas_mods": true,
- "gradient_up_down": true,
- "gradient_left_right": true,
- "breathing": true,
- "band_sat": true,
- "band_val": true,
"band_pinwheel_sat": true,
"band_pinwheel_val": true,
+ "band_sat": true,
"band_spiral_sat": true,
"band_spiral_val": true,
+ "band_val": true,
+ "breathing": true,
"cycle_all": true,
"cycle_left_right": true,
- "cycle_up_down": true,
- "rainbow_moving_chevron": true,
"cycle_out_in": true,
"cycle_out_in_dual": true,
"cycle_pinwheel": true,
"cycle_spiral": true,
+ "cycle_up_down": true,
+ "digital_rain": true,
"dual_beacon": true,
- "rainbow_beacon": true,
- "rainbow_pinwheels": true,
- "raindrops": true,
- "jellybean_raindrops": true,
+ "gradient_left_right": true,
+ "gradient_up_down": true,
"hue_breathing": true,
"hue_pendulum": true,
"hue_wave": true,
- "pixel_rain": true,
+ "jellybean_raindrops": true,
+ "multisplash": true,
"pixel_flow": true,
"pixel_fractal": true,
- "typing_heatmap": true,
- "digital_rain": true,
- "solid_reactive_simple": true,
+ "pixel_rain": true,
+ "rainbow_beacon": true,
+ "rainbow_moving_chevron": true,
+ "rainbow_pinwheels": true,
+ "raindrops": true,
+ "solid_multisplash": true,
"solid_reactive": true,
- "solid_reactive_wide": true,
- "solid_reactive_multiwide": true,
"solid_reactive_cross": true,
"solid_reactive_multicross": true,
- "solid_reactive_nexus": true,
"solid_reactive_multinexus": true,
- "splash": true,
- "multisplash": true,
+ "solid_reactive_multiwide": true,
+ "solid_reactive_nexus": true,
+ "solid_reactive_simple": true,
+ "solid_reactive_wide": true,
"solid_splash": true,
- "solid_multisplash": true
+ "splash": true,
+ "typing_heatmap": true
},
"driver": "ws2812",
"layout": [
- {"flags": 4, "matrix": [4, 14], "x": 224, "y": 64},
- {"flags": 4, "matrix": [4, 13], "x": 208, "y": 64},
- {"flags": 4, "matrix": [4, 12], "x": 192, "y": 64},
- {"flags": 4, "matrix": [4, 11], "x": 176, "y": 64},
- {"flags": 4, "matrix": [4, 10], "x": 160, "y": 64},
- {"flags": 4, "matrix": [4, 9], "x": 144, "y": 64},
- {"flags": 4, "matrix": [4, 8], "x": 128, "y": 64},
- {"flags": 4, "matrix": [4, 7], "x": 112, "y": 64},
- {"flags": 4, "matrix": [4, 6], "x": 96, "y": 64},
- {"flags": 4, "matrix": [4, 5], "x": 80, "y": 64},
- {"flags": 4, "matrix": [4, 4], "x": 64, "y": 64},
- {"flags": 4, "matrix": [4, 3], "x": 48, "y": 64},
- {"flags": 4, "matrix": [4, 2], "x": 32, "y": 64},
- {"flags": 4, "matrix": [4, 1], "x": 16, "y": 64},
- {"flags": 4, "matrix": [4, 0], "x": 0, "y": 64},
- {"flags": 4, "matrix": [3, 14], "x": 224, "y": 48},
- {"flags": 4, "matrix": [3, 13], "x": 208, "y": 48},
- {"flags": 4, "matrix": [3, 12], "x": 192, "y": 48},
- {"flags": 4, "matrix": [3, 11], "x": 176, "y": 48},
- {"flags": 4, "matrix": [3, 10], "x": 160, "y": 48},
- {"flags": 4, "matrix": [3, 9], "x": 144, "y": 48},
- {"flags": 4, "matrix": [3, 8], "x": 128, "y": 48},
- {"flags": 4, "matrix": [3, 7], "x": 112, "y": 48},
- {"flags": 4, "matrix": [3, 6], "x": 96, "y": 48},
- {"flags": 4, "matrix": [3, 5], "x": 80, "y": 48},
- {"flags": 4, "matrix": [3, 4], "x": 64, "y": 48},
- {"flags": 4, "matrix": [3, 3], "x": 48, "y": 48},
- {"flags": 4, "matrix": [3, 2], "x": 32, "y": 48},
- {"flags": 4, "matrix": [3, 1], "x": 16, "y": 48},
- {"flags": 4, "matrix": [3, 0], "x": 0, "y": 48},
- {"flags": 4, "matrix": [2, 14], "x": 224, "y": 32},
- {"flags": 4, "matrix": [2, 13], "x": 208, "y": 32},
- {"flags": 4, "matrix": [2, 12], "x": 192, "y": 32},
- {"flags": 4, "matrix": [2, 11], "x": 176, "y": 32},
- {"flags": 4, "matrix": [2, 10], "x": 160, "y": 32},
- {"flags": 4, "matrix": [2, 9], "x": 144, "y": 32},
- {"flags": 4, "matrix": [2, 8], "x": 128, "y": 32},
- {"flags": 4, "matrix": [2, 7], "x": 112, "y": 32},
- {"flags": 4, "matrix": [2, 6], "x": 96, "y": 32},
- {"flags": 4, "matrix": [2, 5], "x": 80, "y": 32},
- {"flags": 4, "matrix": [2, 4], "x": 64, "y": 32},
- {"flags": 4, "matrix": [2, 3], "x": 48, "y": 32},
- {"flags": 4, "matrix": [2, 2], "x": 32, "y": 32},
- {"flags": 4, "matrix": [2, 1], "x": 16, "y": 32},
- {"flags": 4, "matrix": [2, 0], "x": 0, "y": 32},
- {"flags": 4, "matrix": [1, 14], "x": 224, "y": 16},
- {"flags": 4, "matrix": [1, 13], "x": 208, "y": 16},
- {"flags": 4, "matrix": [1, 12], "x": 192, "y": 16},
- {"flags": 4, "matrix": [1, 11], "x": 176, "y": 16},
- {"flags": 4, "matrix": [1, 10], "x": 160, "y": 16},
- {"flags": 4, "matrix": [1, 9], "x": 144, "y": 16},
- {"flags": 4, "matrix": [1, 8], "x": 128, "y": 16},
- {"flags": 4, "matrix": [1, 7], "x": 112, "y": 16},
- {"flags": 4, "matrix": [1, 6], "x": 96, "y": 16},
- {"flags": 4, "matrix": [1, 5], "x": 80, "y": 16},
- {"flags": 4, "matrix": [1, 4], "x": 64, "y": 16},
- {"flags": 4, "matrix": [1, 3], "x": 48, "y": 16},
- {"flags": 4, "matrix": [1, 2], "x": 32, "y": 16},
- {"flags": 4, "matrix": [1, 1], "x": 16, "y": 16},
- {"flags": 4, "matrix": [1, 0], "x": 0, "y": 16},
- {"flags": 4, "matrix": [0, 14], "x": 224, "y": 0},
- {"flags": 4, "matrix": [0, 13], "x": 208, "y": 0},
- {"flags": 4, "matrix": [0, 12], "x": 192, "y": 0},
- {"flags": 4, "matrix": [0, 11], "x": 176, "y": 0},
- {"flags": 4, "matrix": [0, 10], "x": 160, "y": 0},
- {"flags": 4, "matrix": [0, 9], "x": 144, "y": 0},
- {"flags": 4, "matrix": [0, 8], "x": 128, "y": 0},
- {"flags": 4, "matrix": [0, 7], "x": 112, "y": 0},
- {"flags": 4, "matrix": [0, 6], "x": 96, "y": 0},
- {"flags": 4, "matrix": [0, 5], "x": 80, "y": 0},
- {"flags": 4, "matrix": [0, 4], "x": 64, "y": 0},
- {"flags": 4, "matrix": [0, 3], "x": 48, "y": 0},
- {"flags": 4, "matrix": [0, 2], "x": 32, "y": 0},
- {"flags": 4, "matrix": [0, 1], "x": 16, "y": 0},
- {"flags": 4, "matrix": [0, 0], "x": 0, "y": 0},
- {"flags": 2, "x": 0, "y": 64},
- {"flags": 2, "x": 38, "y": 64},
- {"flags": 2, "x": 76, "y": 64},
- {"flags": 2, "x": 114, "y": 64},
- {"flags": 2, "x": 152, "y": 64},
- {"flags": 2, "x": 190, "y": 64},
- {"flags": 2, "x": 224, "y": 64},
- {"flags": 2, "x": 0, "y": 0},
- {"flags": 2, "x": 38, "y": 0},
- {"flags": 2, "x": 76, "y": 0},
- {"flags": 2, "x": 114, "y": 0},
- {"flags": 2, "x": 152, "y": 0},
- {"flags": 2, "x": 190, "y": 0},
- {"flags": 2, "x": 224, "y": 0}
+ {"matrix": [4, 14], "x": 224, "y": 64, "flags": 4},
+ {"matrix": [4, 13], "x": 208, "y": 64, "flags": 4},
+ {"matrix": [4, 12], "x": 192, "y": 64, "flags": 4},
+ {"matrix": [4, 11], "x": 176, "y": 64, "flags": 4},
+ {"matrix": [4, 10], "x": 160, "y": 64, "flags": 4},
+ {"matrix": [4, 9], "x": 144, "y": 64, "flags": 4},
+ {"matrix": [4, 8], "x": 128, "y": 64, "flags": 4},
+ {"matrix": [4, 7], "x": 112, "y": 64, "flags": 4},
+ {"matrix": [4, 6], "x": 96, "y": 64, "flags": 4},
+ {"matrix": [4, 5], "x": 80, "y": 64, "flags": 4},
+ {"matrix": [4, 4], "x": 64, "y": 64, "flags": 4},
+ {"matrix": [4, 3], "x": 48, "y": 64, "flags": 4},
+ {"matrix": [4, 2], "x": 32, "y": 64, "flags": 4},
+ {"matrix": [4, 1], "x": 16, "y": 64, "flags": 4},
+ {"matrix": [4, 0], "x": 0, "y": 64, "flags": 4},
+ {"matrix": [3, 14], "x": 224, "y": 48, "flags": 4},
+ {"matrix": [3, 13], "x": 208, "y": 48, "flags": 4},
+ {"matrix": [3, 12], "x": 192, "y": 48, "flags": 4},
+ {"matrix": [3, 11], "x": 176, "y": 48, "flags": 4},
+ {"matrix": [3, 10], "x": 160, "y": 48, "flags": 4},
+ {"matrix": [3, 9], "x": 144, "y": 48, "flags": 4},
+ {"matrix": [3, 8], "x": 128, "y": 48, "flags": 4},
+ {"matrix": [3, 7], "x": 112, "y": 48, "flags": 4},
+ {"matrix": [3, 6], "x": 96, "y": 48, "flags": 4},
+ {"matrix": [3, 5], "x": 80, "y": 48, "flags": 4},
+ {"matrix": [3, 4], "x": 64, "y": 48, "flags": 4},
+ {"matrix": [3, 3], "x": 48, "y": 48, "flags": 4},
+ {"matrix": [3, 2], "x": 32, "y": 48, "flags": 4},
+ {"matrix": [3, 1], "x": 16, "y": 48, "flags": 4},
+ {"matrix": [3, 0], "x": 0, "y": 48, "flags": 4},
+ {"matrix": [2, 14], "x": 224, "y": 32, "flags": 4},
+ {"matrix": [2, 13], "x": 208, "y": 32, "flags": 4},
+ {"matrix": [2, 12], "x": 192, "y": 32, "flags": 4},
+ {"matrix": [2, 11], "x": 176, "y": 32, "flags": 4},
+ {"matrix": [2, 10], "x": 160, "y": 32, "flags": 4},
+ {"matrix": [2, 9], "x": 144, "y": 32, "flags": 4},
+ {"matrix": [2, 8], "x": 128, "y": 32, "flags": 4},
+ {"matrix": [2, 7], "x": 112, "y": 32, "flags": 4},
+ {"matrix": [2, 6], "x": 96, "y": 32, "flags": 4},
+ {"matrix": [2, 5], "x": 80, "y": 32, "flags": 4},
+ {"matrix": [2, 4], "x": 64, "y": 32, "flags": 4},
+ {"matrix": [2, 3], "x": 48, "y": 32, "flags": 4},
+ {"matrix": [2, 2], "x": 32, "y": 32, "flags": 4},
+ {"matrix": [2, 1], "x": 16, "y": 32, "flags": 4},
+ {"matrix": [2, 0], "x": 0, "y": 32, "flags": 4},
+ {"matrix": [1, 14], "x": 224, "y": 16, "flags": 4},
+ {"matrix": [1, 13], "x": 208, "y": 16, "flags": 4},
+ {"matrix": [1, 12], "x": 192, "y": 16, "flags": 4},
+ {"matrix": [1, 11], "x": 176, "y": 16, "flags": 4},
+ {"matrix": [1, 10], "x": 160, "y": 16, "flags": 4},
+ {"matrix": [1, 9], "x": 144, "y": 16, "flags": 4},
+ {"matrix": [1, 8], "x": 128, "y": 16, "flags": 4},
+ {"matrix": [1, 7], "x": 112, "y": 16, "flags": 4},
+ {"matrix": [1, 6], "x": 96, "y": 16, "flags": 4},
+ {"matrix": [1, 5], "x": 80, "y": 16, "flags": 4},
+ {"matrix": [1, 4], "x": 64, "y": 16, "flags": 4},
+ {"matrix": [1, 3], "x": 48, "y": 16, "flags": 4},
+ {"matrix": [1, 2], "x": 32, "y": 16, "flags": 4},
+ {"matrix": [1, 1], "x": 16, "y": 16, "flags": 4},
+ {"matrix": [1, 0], "x": 0, "y": 16, "flags": 4},
+ {"matrix": [0, 14], "x": 224, "y": 0, "flags": 4},
+ {"matrix": [0, 13], "x": 208, "y": 0, "flags": 4},
+ {"matrix": [0, 12], "x": 192, "y": 0, "flags": 4},
+ {"matrix": [0, 11], "x": 176, "y": 0, "flags": 4},
+ {"matrix": [0, 10], "x": 160, "y": 0, "flags": 4},
+ {"matrix": [0, 9], "x": 144, "y": 0, "flags": 4},
+ {"matrix": [0, 8], "x": 128, "y": 0, "flags": 4},
+ {"matrix": [0, 7], "x": 112, "y": 0, "flags": 4},
+ {"matrix": [0, 6], "x": 96, "y": 0, "flags": 4},
+ {"matrix": [0, 5], "x": 80, "y": 0, "flags": 4},
+ {"matrix": [0, 4], "x": 64, "y": 0, "flags": 4},
+ {"matrix": [0, 3], "x": 48, "y": 0, "flags": 4},
+ {"matrix": [0, 2], "x": 32, "y": 0, "flags": 4},
+ {"matrix": [0, 1], "x": 16, "y": 0, "flags": 4},
+ {"matrix": [0, 0], "x": 0, "y": 0, "flags": 4},
+ {"x": 0, "y": 64, "flags": 2},
+ {"x": 38, "y": 64, "flags": 2},
+ {"x": 76, "y": 64, "flags": 2},
+ {"x": 114, "y": 64, "flags": 2},
+ {"x": 152, "y": 64, "flags": 2},
+ {"x": 190, "y": 64, "flags": 2},
+ {"x": 224, "y": 64, "flags": 2},
+ {"x": 0, "y": 0, "flags": 2},
+ {"x": 38, "y": 0, "flags": 2},
+ {"x": 76, "y": 0, "flags": 2},
+ {"x": 114, "y": 0, "flags": 2},
+ {"x": 152, "y": 0, "flags": 2},
+ {"x": 190, "y": 0, "flags": 2},
+ {"x": 224, "y": 0, "flags": 2}
],
"max_brightness": 128,
"sleep": true
diff --git a/keyboards/ymdk/id75/readme.md b/keyboards/ymdk/id75/readme.md
index 9315745f71..4f7e779458 100644
--- a/keyboards/ymdk/id75/readme.md
+++ b/keyboards/ymdk/id75/readme.md
@@ -5,17 +5,18 @@
A 75-key, 5-row ortholinear keyboard with per-key and underglow RGB LEDs.
* Keyboard Maintainer: [The QMK Community](https://github.com/qmk)
-* Hardware Supported: [Idobao x YMDK ID75 PCB (APM32F103CBT6)](https://www.aliexpress.com/item/3256804537842097.html)
- * This PCB uses an ARM Cortex-M3 MCU with 128kb flash. **It is not the same as `idobao/id75` or `ymdk/ymd75`.**
+* Hardware Supported: [Idobao x YMDK ID75](https://www.aliexpress.com/item/3256804537842097.html). **This is not the same PCB as `idobao/id75` or `ymdk/ymd75`.**
+ This keyboard has had multiple PCB revisions, some of which may not work with the firmware in this repository. **Check your PCB before flashing.**
+ * `f103`: (Geehy APM32F103CBT6, uf2boot)
* Hardware Availability: [YMDK](https://ymdkey.com/products/id75-75-keys-ortholinear-layout-qmk-anodized-aluminum-case-plate-hot-swappable-hot-swap-type-c-pcb-mechanical-keyboard-kit), [AliExpress (YMDK Store)](https://www.aliexpress.com/item/2255800125183974.html), [Amazon](https://www.amazon.com/Ortholinear-Anodized-Aluminum-hot-swappable-Mechanical/dp/B07ZQ8CD88)
Make example for this keyboard (after setting up your build environment):
- make ymdk/id75:default
+ make ymdk/id75/f103:default
Flashing example for this keyboard:
- make ymdk/id75:default:flash
+ make ymdk/id75/f103:default:flash
See the [build environment setup](https://docs.qmk.fm/#/getting_started_build_tools) and the [make instructions](https://docs.qmk.fm/#/getting_started_make_guide) for more information. Brand new to QMK? Start with our [Complete Newbs Guide](https://docs.qmk.fm/#/newbs).
@@ -27,4 +28,5 @@ Enter the bootloader in 3 ways:
* **Physical reset button**: Press the button on the back of the PCB twice in quick succession.
* **Keycode in layout**: Press the key mapped to `QK_BOOT`. In the pre-supplied keymaps it is on the second layer, in the bottom-right corner.
-After entering the bootloader through one of the three methods above, the keyboard will appear as a USB mass storage device named `MT.KEY`. If the CLI is unable to find this device, the compiled `.uf2` file can be manually copied to it. The keyboard will reboot on completion with the new firmware loaded.
+After entering the bootloader through one of the three methods above, the keyboard will appear as a USB mass storage device. If the CLI is unable to find this device, the compiled `.uf2` file can be manually copied to it. The keyboard will reboot on completion with the new firmware loaded.
+- `f103`: The volume name is `MT.KEY`.
diff --git a/lib/chibios b/lib/chibios
-Subproject be44b3305f9a9fe5f2f49a4e7b978db322dc463
+Subproject 2365f844292513ea0ee9eea6ab778d56f9ccd3b
diff --git a/lib/chibios-contrib b/lib/chibios-contrib
-Subproject 77cb0a4f7589f89e724f5e6ecb1d76d514dd121
+Subproject b643aad980d061021565c55745925c2cde4a3c6
diff --git a/lib/python/qmk/cli/generate/keyboard_h.py b/lib/python/qmk/cli/generate/keyboard_h.py
index 5863a0983a..cb9528d96b 100755
--- a/lib/python/qmk/cli/generate/keyboard_h.py
+++ b/lib/python/qmk/cli/generate/keyboard_h.py
@@ -22,6 +22,11 @@ def _generate_layouts(keyboard, kb_info_json):
row_num = kb_info_json['matrix_size']['rows']
lines = []
+ lines.append('')
+ lines.append('// Layout content')
+ lines.append('')
+ lines.append('#define XXX KC_NO')
+
for layout_name, layout_data in kb_info_json['layouts'].items():
if layout_data['c_macro']:
continue
@@ -31,7 +36,7 @@ def _generate_layouts(keyboard, kb_info_json):
continue
layout_keys = []
- layout_matrix = [['KC_NO'] * col_num for _ in range(row_num)]
+ layout_matrix = [['XXX'] * col_num for _ in range(row_num)]
for key_data in layout_data['layout']:
row, col = key_data['matrix']
@@ -46,7 +51,7 @@ def _generate_layouts(keyboard, kb_info_json):
lines.append('')
lines.append(f'#define {layout_name}({", ".join(layout_keys)}) {{ \\')
- rows = ', \\\n'.join(['\t {' + ', '.join(row) + '}' for row in layout_matrix])
+ rows = ', \\\n'.join([' { ' + ', '.join(row) + ' }' for row in layout_matrix])
rows += ' \\'
lines.append(rows)
lines.append('}')
@@ -67,6 +72,9 @@ def _generate_keycodes(kb_info_json):
return []
lines = []
+ lines.append('')
+ lines.append('// Keycode content')
+ lines.append('')
lines.append('enum keyboard_keycodes {')
for index, item in enumerate(kb_info_json.get('keycodes')):
@@ -103,17 +111,14 @@ def generate_keyboard_h(cli):
valid_config = dd_layouts or keyboard_h
# Build the layouts.h file.
- keyboard_h_lines = [GPL2_HEADER_C_LIKE, GENERATED_HEADER_C_LIKE, '#pragma once', '#include "quantum.h"']
+ keyboard_h_lines = [GPL2_HEADER_C_LIKE, GENERATED_HEADER_C_LIKE, '#pragma once', '', '#include "quantum.h"']
- keyboard_h_lines.append('')
- keyboard_h_lines.append('// Layout content')
if dd_layouts:
keyboard_h_lines.extend(dd_layouts)
+
if keyboard_h:
keyboard_h_lines.append(f'#include "{Path(keyboard_h).name}"')
- keyboard_h_lines.append('')
- keyboard_h_lines.append('// Keycode content')
if dd_keycodes:
keyboard_h_lines.extend(dd_keycodes)
diff --git a/lib/python/qmk/cli/new/keymap.py b/lib/python/qmk/cli/new/keymap.py
index f1df05636c..8b7160f5f2 100755
--- a/lib/python/qmk/cli/new/keymap.py
+++ b/lib/python/qmk/cli/new/keymap.py
@@ -23,19 +23,17 @@ def validate_keymap_name(name):
def prompt_keyboard():
prompt = """{fg_yellow}Select Keyboard{style_reset_all}
-If you`re unsure you can view a full list of supported keyboards with {fg_yellow}qmk list-keyboards{style_reset_all}.
+If you're unsure you can view a full list of supported keyboards with {fg_yellow}qmk list-keyboards{style_reset_all}.
Keyboard Name? """
-
return question(prompt)
def prompt_user():
prompt = """
{fg_yellow}Name Your Keymap{style_reset_all}
-Used for maintainer, copyright, etc
-Your GitHub Username? """
+Keymap name? """
return question(prompt, default=git_get_username())
diff --git a/platforms/chibios/boards/GENERIC_STM32_H723XG/configs/mcuconf.h b/platforms/chibios/boards/GENERIC_STM32_H723XG/configs/mcuconf.h
index 0239ec5273..09096c3977 100644
--- a/platforms/chibios/boards/GENERIC_STM32_H723XG/configs/mcuconf.h
+++ b/platforms/chibios/boards/GENERIC_STM32_H723XG/configs/mcuconf.h
@@ -182,6 +182,7 @@
#define STM32_IRQ_FDCAN1_PRIORITY 10
#define STM32_IRQ_FDCAN2_PRIORITY 10
+#define STM32_IRQ_FDCAN3_PRIORITY 10
#define STM32_IRQ_MDMA_PRIORITY 9
@@ -235,6 +236,7 @@
*/
#define STM32_CAN_USE_FDCAN1 FALSE
#define STM32_CAN_USE_FDCAN2 FALSE
+#define STM32_CAN_USE_FDCAN3 FALSE
/*
* DAC driver system settings.
diff --git a/platforms/chibios/boards/QMK_PROTON_C/configs/chconf.h b/platforms/chibios/boards/QMK_PROTON_C/configs/chconf.h
index cc10304a3f..e92b7aeb98 100644
--- a/platforms/chibios/boards/QMK_PROTON_C/configs/chconf.h
+++ b/platforms/chibios/boards/QMK_PROTON_C/configs/chconf.h
@@ -49,6 +49,19 @@
#define CH_CFG_SMP_MODE FALSE
#endif
+/**
+ * @brief Kernel hardening level.
+ * @details This option is the level of functional-safety checks enabled
+ * in the kerkel. The meaning is:
+ * - 0: No checks, maximum performance.
+ * - 1: Reasonable checks.
+ * - 2: All checks.
+ * .
+ */
+#if !defined(CH_CFG_HARDENING_LEVEL)
+#define CH_CFG_HARDENING_LEVEL 0
+#endif
+
/** @} */
/*===========================================================================*/
@@ -361,6 +374,16 @@
#endif
/**
+ * @brief Memory checks APIs.
+ * @details If enabled then the memory checks APIs are included in the kernel.
+ *
+ * @note The default is @p TRUE.
+ */
+#if !defined(CH_CFG_USE_MEMCHECKS)
+#define CH_CFG_USE_MEMCHECKS TRUE
+#endif
+
+/**
* @brief Core Memory Manager APIs.
* @details If enabled then the core memory manager APIs are included
* in the kernel.
diff --git a/platforms/chibios/boards/common/configs/chconf.h b/platforms/chibios/boards/common/configs/chconf.h
index 5db836e37c..6381298ef7 100644
--- a/platforms/chibios/boards/common/configs/chconf.h
+++ b/platforms/chibios/boards/common/configs/chconf.h
@@ -49,6 +49,19 @@
#define CH_CFG_SMP_MODE FALSE
#endif
+/**
+ * @brief Kernel hardening level.
+ * @details This option is the level of functional-safety checks enabled
+ * in the kerkel. The meaning is:
+ * - 0: No checks, maximum performance.
+ * - 1: Reasonable checks.
+ * - 2: All checks.
+ * .
+ */
+#if !defined(CH_CFG_HARDENING_LEVEL)
+#define CH_CFG_HARDENING_LEVEL 0
+#endif
+
/** @} */
/*===========================================================================*/
@@ -361,6 +374,16 @@
#endif
/**
+ * @brief Memory checks APIs.
+ * @details If enabled then the memory checks APIs are included in the kernel.
+ *
+ * @note The default is @p TRUE.
+ */
+#if !defined(CH_CFG_USE_MEMCHECKS)
+#define CH_CFG_USE_MEMCHECKS TRUE
+#endif
+
+/**
* @brief Core Memory Manager APIs.
* @details If enabled then the core memory manager APIs are included
* in the kernel.
diff --git a/platforms/chibios/drivers/audio_pwm_hardware.c b/platforms/chibios/drivers/audio_pwm_hardware.c
index 1ba7ec13bc..afa341abb6 100644
--- a/platforms/chibios/drivers/audio_pwm_hardware.c
+++ b/platforms/chibios/drivers/audio_pwm_hardware.c
@@ -41,18 +41,19 @@ static float channel_1_frequency = 0.0f;
void channel_1_set_frequency(float freq) {
channel_1_frequency = freq;
+ pwmcnt_t period;
+ pwmcnt_t width;
if (freq <= 0.0) {
- // a pause/rest has freq=0
- return;
+ period = 2;
+ width = 0;
+ } else {
+ period = (pwmCFG.frequency / freq);
+ width = (pwmcnt_t)(((period) * (pwmcnt_t)((100 - note_timbre) * 100)) / (pwmcnt_t)(10000));
}
-
- pwmcnt_t period = (pwmCFG.frequency / freq);
chSysLockFromISR();
pwmChangePeriodI(&AUDIO_PWM_DRIVER, period);
- pwmEnableChannelI(&AUDIO_PWM_DRIVER, AUDIO_PWM_CHANNEL - 1,
- // adjust the duty-cycle so that the output is for 'note_timbre' duration HIGH
- PWM_PERCENTAGE_TO_WIDTH(&AUDIO_PWM_DRIVER, (100 - note_timbre) * 100));
+ pwmEnableChannelI(&AUDIO_PWM_DRIVER, AUDIO_PWM_CHANNEL - 1, width);
chSysUnlockFromISR();
}
@@ -67,6 +68,9 @@ void channel_1_start(void) {
void channel_1_stop(void) {
pwmStop(&AUDIO_PWM_DRIVER);
+ pwmStart(&AUDIO_PWM_DRIVER, &pwmCFG);
+ pwmEnableChannel(&AUDIO_PWM_DRIVER, AUDIO_PWM_CHANNEL - 1, 0);
+ pwmStop(&AUDIO_PWM_DRIVER);
}
static virtual_timer_t audio_vt;
diff --git a/platforms/chibios/timer.c b/platforms/chibios/timer.c
index 4a347b445d..a07cf5714f 100644
--- a/platforms/chibios/timer.c
+++ b/platforms/chibios/timer.c
@@ -99,7 +99,7 @@ uint16_t timer_read(void) {
}
uint32_t timer_read32(void) {
- chSysLock();
+ syssts_t sts = chSysGetStatusAndLockX();
uint32_t ticks = get_system_time_ticks() - ticks_offset;
if (ticks < last_ticks) {
// The 32-bit tick counter overflowed and wrapped around. We cannot just extend the counter to 64 bits here,
@@ -114,7 +114,7 @@ uint32_t timer_read32(void) {
}
last_ticks = ticks;
uint32_t ms_offset_copy = ms_offset; // read while still holding the lock to ensure a consistent value
- chSysUnlock();
+ chSysRestoreStatusX(sts);
return (uint32_t)TIME_I2MS(ticks) + ms_offset_copy;
}
diff --git a/platforms/timer.h b/platforms/timer.h
index fb8ff6bc54..8a2ffd476b 100644
--- a/platforms/timer.h
+++ b/platforms/timer.h
@@ -24,10 +24,9 @@ along with this program. If not, see <http://www.gnu.org/licenses/>.
#include <stdint.h>
-#define TIMER_DIFF(a, b, max) ((max == UINT8_MAX) ? ((uint8_t)((a) - (b))) : ((max == UINT16_MAX) ? ((uint16_t)((a) - (b))) : ((max == UINT32_MAX) ? ((uint32_t)((a) - (b))) : ((a) >= (b) ? (a) - (b) : (max) + 1 - (b) + (a)))))
-#define TIMER_DIFF_8(a, b) TIMER_DIFF(a, b, UINT8_MAX)
-#define TIMER_DIFF_16(a, b) TIMER_DIFF(a, b, UINT16_MAX)
-#define TIMER_DIFF_32(a, b) TIMER_DIFF(a, b, UINT32_MAX)
+#define TIMER_DIFF_8(a, b) (uint8_t)((a) - (b))
+#define TIMER_DIFF_16(a, b) (uint16_t)((a) - (b))
+#define TIMER_DIFF_32(a, b) (uint32_t)((a) - (b))
#define TIMER_DIFF_RAW(a, b) TIMER_DIFF_8(a, b)
#ifdef __cplusplus
diff --git a/quantum/audio/audio.c b/quantum/audio/audio.c
index b2611c5f09..2cc3c2d661 100644
--- a/quantum/audio/audio.c
+++ b/quantum/audio/audio.c
@@ -258,11 +258,10 @@ void audio_stop_tone(float pitch) {
for (int i = AUDIO_TONE_STACKSIZE - 1; i >= 0; i--) {
found = (tones[i].pitch == pitch);
if (found) {
- tones[i] = (musical_tone_t){.time_started = 0, .pitch = -1.0f, .duration = 0};
for (int j = i; (j < AUDIO_TONE_STACKSIZE - 1); j++) {
- tones[j] = tones[j + 1];
- tones[j + 1] = (musical_tone_t){.time_started = 0, .pitch = -1.0f, .duration = 0};
+ tones[j] = tones[j + 1];
}
+ tones[AUDIO_TONE_STACKSIZE - 1] = (musical_tone_t){.time_started = 0, .pitch = -1.0f, .duration = 0};
break;
}
}
diff --git a/quantum/keymap_extras/keymap_eurkey.h b/quantum/keymap_extras/keymap_eurkey.h
new file mode 100644
index 0000000000..20f7f58683
--- /dev/null
+++ b/quantum/keymap_extras/keymap_eurkey.h
@@ -0,0 +1,166 @@
+// Copyright 2025 QMK
+// SPDX-License-Identifier: GPL-2.0-or-later
+
+/*******************************************************************************
+ 88888888888 888 d8b .d888 d8b 888 d8b
+ 888 888 Y8P d88P" Y8P 888 Y8P
+ 888 888 888 888
+ 888 88888b. 888 .d8888b 888888 888 888 .d88b. 888 .d8888b
+ 888 888 "88b 888 88K 888 888 888 d8P Y8b 888 88K
+ 888 888 888 888 "Y8888b. 888 888 888 88888888 888 "Y8888b.
+ 888 888 888 888 X88 888 888 888 Y8b. 888 X88
+ 888 888 888 888 88888P' 888 888 888 "Y8888 888 88888P'
+ 888 888
+ 888 888
+ 888 888
+ .d88b. .d88b. 88888b. .d88b. 888d888 8888b. 888888 .d88b. .d88888
+ d88P"88b d8P Y8b 888 "88b d8P Y8b 888P" "88b 888 d8P Y8b d88" 888
+ 888 888 88888888 888 888 88888888 888 .d888888 888 88888888 888 888
+ Y88b 888 Y8b. 888 888 Y8b. 888 888 888 Y88b. Y8b. Y88b 888
+ "Y88888 "Y8888 888 888 "Y8888 888 "Y888888 "Y888 "Y8888 "Y88888
+ 888
+ Y8b d88P
+ "Y88P"
+*******************************************************************************/
+
+#pragma once
+#include "keycodes.h"
+// clang-format off
+
+// Aliases
+#define EU_GRV KC_GRV // `
+#define EU_1 KC_1 // 1
+#define EU_2 KC_2 // 2
+#define EU_3 KC_3 // 3
+#define EU_4 KC_4 // 4
+#define EU_5 KC_5 // 5
+#define EU_6 KC_6 // 6
+#define EU_7 KC_7 // 7
+#define EU_8 KC_8 // 8
+#define EU_9 KC_9 // 9
+#define EU_0 KC_0 // 0
+#define EU_MINS KC_MINS // -
+#define EU_EQL KC_EQL // =
+#define EU_Q KC_Q // Q
+#define EU_W KC_W // W
+#define EU_E KC_E // E
+#define EU_R KC_R // R
+#define EU_T KC_T // T
+#define EU_Y KC_Y // Y
+#define EU_U KC_U // U
+#define EU_I KC_I // I
+#define EU_O KC_O // O
+#define EU_P KC_P // P
+#define EU_LBRC KC_LBRC // [
+#define EU_RBRC KC_RBRC // ]
+#define EU_BSLS KC_BSLS // (backslash)
+#define EU_A KC_A // A
+#define EU_S KC_S // S
+#define EU_D KC_D // D
+#define EU_F KC_F // F
+#define EU_G KC_G // G
+#define EU_H KC_H // H
+#define EU_J KC_J // J
+#define EU_K KC_K // K
+#define EU_L KC_L // L
+#define EU_SCLN KC_SCLN // ;
+#define EU_QUOT KC_QUOT // '
+#define EU_Z KC_Z // Z
+#define EU_X KC_X // X
+#define EU_C KC_C // C
+#define EU_V KC_V // V
+#define EU_B KC_B // B
+#define EU_N KC_N // N
+#define EU_M KC_M // M
+#define EU_COMM KC_COMM // ,
+#define EU_DOT KC_DOT // .
+#define EU_SLSH KC_SLSH // /
+#define EU_TILD S(EU_GRV) // ~
+#define EU_EXLM S(EU_1) // !
+#define EU_AT S(EU_2) // @
+#define EU_HASH S(EU_3) // #
+#define EU_DLR S(EU_4) // $
+#define EU_PERC S(EU_5) // %
+#define EU_CIRC S(EU_6) // ^
+#define EU_AMPR S(EU_7) // &
+#define EU_ASTR S(EU_8) // *
+#define EU_LPRN S(EU_9) // (
+#define EU_RPRN S(EU_0) // )
+#define EU_UNDS S(EU_MINS) // _
+#define EU_PLUS S(EU_EQL) // +
+#define EU_LCBR S(EU_LBRC) // {
+#define EU_RCBR S(EU_RBRC) // }
+#define EU_PIPE S(EU_BSLS) // |
+#define EU_COLN S(EU_SCLN) // :
+#define EU_DQUO S(EU_QUOT) // "
+#define EU_LABK S(EU_COMM) // <
+#define EU_RABK S(EU_DOT) // >
+#define EU_QUES S(EU_SLSH) // ?
+#define EU_DGRV ALGR(EU_GRV) // ` (dead)
+#define EU_IEXL ALGR(EU_1) // ¡
+#define EU_FORD ALGR(EU_2) // ª
+#define EU_MORD ALGR(EU_3) // º
+#define EU_PND ALGR(EU_4) // £
+#define EU_EURO ALGR(EU_5) // €
+#define EU_DCIR ALGR(EU_6) // ^ (dead)
+#define EU_RNGA ALGR(EU_7) // ˚ (dead)
+#define EU_DLQU ALGR(EU_8) // „
+#define EU_LDQU ALGR(EU_9) // “
+#define EU_RDQU ALGR(EU_0) // ”
+#define EU_NDSH ALGR(EU_MINS) // –
+#define EU_MUL ALGR(EU_EQL) // ×
+#define EU_AE ALGR(EU_Q) // æ
+#define EU_ARNG ALGR(EU_W) // Å
+#define EU_EDIA ALGR(EU_E) // Ë
+#define EU_YACU ALGR(EU_R) // Ý
+#define EU_THRN ALGR(EU_T) // Þ
+#define EU_YDIA ALGR(EU_Y) // Ÿ
+#define EU_UDIA ALGR(EU_U) // Ü
+#define EU_IDIA ALGR(EU_I) // Ï
+#define EU_ODIA ALGR(EU_O) // Ö
+#define EU_OE ALGR(EU_P) // Œ
+#define EU_LDAQ ALGR(EU_LBRC) // «
+#define EU_RDAQ ALGR(EU_RBRC) // »
+#define EU_NOT ALGR(EU_BSLS) // ¬
+#define EU_ADIA ALGR(EU_A) // Ä
+#define EU_SS ALGR(EU_S) // ß
+#define EU_ETH ALGR(EU_D) // Ð
+#define EU_EGRV ALGR(EU_F) // È
+#define EU_EACU ALGR(EU_G) // É
+#define EU_UGRV ALGR(EU_H) // Ù
+#define EU_UACU ALGR(EU_J) // Ú
+#define EU_IJ ALGR(EU_K) // IJ
+#define EU_OSTR ALGR(EU_L) // Ø
+#define EU_DEG ALGR(EU_SCLN) // °
+#define EU_ACUT ALGR(EU_QUOT) // ´ (dead)
+#define EU_AGRV ALGR(EU_Z) // À
+#define EU_AACU ALGR(EU_X) // Á
+#define EU_CCED ALGR(EU_C) // Ç
+#define EU_IGRV ALGR(EU_V) // Ì
+#define EU_IACU ALGR(EU_B) // Í
+#define EU_NTIL ALGR(EU_N) // Ñ
+#define EU_DGRK ALGR(EU_M) // μ (dead Greek key)
+#define EU_OGRV ALGR(EU_COMM) // Ò
+#define EU_OACU ALGR(EU_DOT) // Ó
+#define EU_IQUE ALGR(EU_SLSH) // ¿
+#define EU_DTIL ALGR(EU_TILD) // ~ (dead)
+#define EU_SUP1 S(ALGR(EU_1)) // ¹
+#define EU_SUP2 S(ALGR(EU_2)) // ²
+#define EU_SUP3 S(ALGR(EU_3)) // ³
+#define EU_YEN ALGR(EU_DLR) // ¥
+#define EU_CENT S(EU_EURO) // ¢
+#define EU_CARN S(EU_DCIR) // ˇ (dead)
+#define EU_MACR S(ALGR(EU_7)) // ¯ (dead)
+#define EU_SLQU S(EU_DLQU) // ‚
+#define EU_LSQU S(EU_LDQU) // ‘
+#define EU_RSQU S(EU_RDQU) // ’
+#define EU_MDSH S(EU_NDSH) // —
+#define EU_DIV S(EU_MUL) // ÷
+#define EU_LSAQ S(EU_LDAQ) // ‹
+#define EU_RSAQ S(EU_RDAQ) // ›
+#define EU_BRKP S(ALGR(EU_BSLS)) // ¦
+#define EU_SECT S(ALGR(EU_S)) // §
+#define EU_MDDT S(ALGR(EU_SCLN)) // ·
+#define EU_DIAE ALGR(EU_DQUO) // ¨ (dead)
+#define EU_ELLP ALGR(EU_QUES) // …
+
diff --git a/quantum/keymap_extras/keymap_farsi.h b/quantum/keymap_extras/keymap_farsi.h
index 8e16188a8f..4f34b08d92 100644
--- a/quantum/keymap_extras/keymap_farsi.h
+++ b/quantum/keymap_extras/keymap_farsi.h
@@ -150,7 +150,7 @@
#define FA_DQT ALGR(FA_GAF) // "
#define FA_MINA ALGR(FA_BSLS) // -
#define FA_PIPE ALGR(FA_ZA) // |
-#define FA_SUBA ALGR(FA_RA) // ٖ
+#define FA_SUBA ALGR(FA_RE) // ٖ
#define FA_HMZB ALGR(FA_DAL) // ء
#define FA_ELLP ALGR(FA_PE) // …
#define FA_COMM ALGR(FA_WAW) // ,
diff --git a/quantum/leader.c b/quantum/leader.c
index 272609ad0c..23e5e8cd6d 100644
--- a/quantum/leader.c
+++ b/quantum/leader.c
@@ -21,6 +21,10 @@ __attribute__((weak)) void leader_start_user(void) {}
__attribute__((weak)) void leader_end_user(void) {}
+__attribute__((weak)) bool leader_add_user(uint16_t keycode) {
+ return false;
+}
+
void leader_start(void) {
if (leading) {
return;
@@ -61,6 +65,9 @@ bool leader_sequence_add(uint16_t keycode) {
leader_sequence[leader_sequence_size] = keycode;
leader_sequence_size++;
+ if (leader_add_user(keycode)) {
+ leader_end();
+ }
return true;
}
diff --git a/quantum/leader.h b/quantum/leader.h
index 3177fcd196..fba6b287ba 100644
--- a/quantum/leader.h
+++ b/quantum/leader.h
@@ -22,6 +22,15 @@ void leader_start_user(void);
void leader_end_user(void);
/**
+ * \brief User callback, invoked when a keycode is added to the leader sequence.
+ *
+ * \param keycode The keycode added to the leader sequence.
+ *
+ * \return `true` to finish the key sequence, `false` to continue.
+ */
+bool leader_add_user(uint16_t keycode);
+
+/**
* Begin the leader sequence, resetting the buffer and timer.
*/
void leader_start(void);
diff --git a/quantum/painter/qgf.c b/quantum/painter/qgf.c
index bc2df94933..07c3f80314 100644
--- a/quantum/painter/qgf.c
+++ b/quantum/painter/qgf.c
@@ -255,10 +255,10 @@ bool qgf_validate_stream(qp_stream_t *stream) {
// Read and validate all the frames (automatically validates the frame offset descriptor in the process)
for (uint16_t i = 0; i < frame_count; ++i) {
// Validate the frame descriptor block
- uint8_t bpp;
- bool has_palette;
- bool is_panel_native;
- bool has_delta;
+ uint8_t bpp = 0;
+ bool has_palette = false;
+ bool is_panel_native = false;
+ bool has_delta = false;
if (!qgf_validate_frame_descriptor(stream, i, &bpp, &has_palette, &is_panel_native, &has_delta)) {
return false;
}
diff --git a/quantum/painter/qp_draw_image.c b/quantum/painter/qp_draw_image.c
index 18fa38cb19..a225039af4 100644
--- a/quantum/painter/qp_draw_image.c
+++ b/quantum/painter/qp_draw_image.c
@@ -318,9 +318,9 @@ static deferred_token qp_render_animation_state(animation_state_t *state, uint16
}
static uint32_t animation_callback(uint32_t trigger_time, void *cb_arg) {
- animation_state_t *state = (animation_state_t *)cb_arg;
- uint16_t delay_ms;
- bool ret = qp_render_animation_state(state, &delay_ms);
+ animation_state_t *state = (animation_state_t *)cb_arg;
+ uint16_t delay_ms = 0;
+ bool ret = qp_render_animation_state(state, &delay_ms);
if (!ret) {
// Setting the device to NULL clears the animation slot
state->device = NULL;
diff --git a/quantum/rgb_matrix/animations/hue_breathing_anim.h b/quantum/rgb_matrix/animations/hue_breathing_anim.h
index 5316e92dbd..60d7426cfc 100644
--- a/quantum/rgb_matrix/animations/hue_breathing_anim.h
+++ b/quantum/rgb_matrix/animations/hue_breathing_anim.h
@@ -2,21 +2,17 @@
RGB_MATRIX_EFFECT(HUE_BREATHING)
# ifdef RGB_MATRIX_CUSTOM_EFFECT_IMPLS
-// Change huedelta to adjust range of hue change. 0-255.
// Hue Breathing - All LED's light up
+hsv_t HUE_BREATHING_math(hsv_t hsv, uint8_t i, uint8_t time) {
+ // Adjust delta between 0-255 to change hue range
+ uint8_t delta = 12;
+ hsv.h = hsv.h + scale8(abs8(sin8(time / 2) - 128) * 2, delta);
+ return hsv;
+}
+
bool HUE_BREATHING(effect_params_t* params) {
- RGB_MATRIX_USE_LIMITS(led_min, led_max);
- uint8_t huedelta = 12;
- hsv_t hsv = rgb_matrix_config.hsv;
- uint16_t time = scale16by8(g_rgb_timer, rgb_matrix_config.speed / 8);
- hsv.h = hsv.h + scale8(abs8(sin8(time) - 128) * 2, huedelta);
- rgb_t rgb = hsv_to_rgb(hsv);
- for (uint8_t i = led_min; i < led_max; i++) {
- RGB_MATRIX_TEST_LED_FLAGS();
- rgb_matrix_set_color(i, rgb.r, rgb.g, rgb.b);
- }
- return rgb_matrix_check_finished_leds(led_max);
+ return effect_runner_i(params, &HUE_BREATHING_math);
}
# endif // RGB_MATRIX_CUSTOM_EFFECT_IMPLS
-#endif // DISABLE_RGB_HUE_BREATHING
+#endif // ENABLE_RGB_MATRIX_HUE_BREATHING
diff --git a/quantum/rgb_matrix/animations/raindrops_anim.h b/quantum/rgb_matrix/animations/raindrops_anim.h
index a682156da2..d4f79adb56 100644
--- a/quantum/rgb_matrix/animations/raindrops_anim.h
+++ b/quantum/rgb_matrix/animations/raindrops_anim.h
@@ -2,35 +2,42 @@
RGB_MATRIX_EFFECT(RAINDROPS)
# ifdef RGB_MATRIX_CUSTOM_EFFECT_IMPLS
-static void raindrops_set_color(int i, effect_params_t* params) {
+static void raindrops_set_color(uint8_t i, effect_params_t* params) {
if (!HAS_ANY_FLAGS(g_led_config.flags[i], params->flags)) return;
- hsv_t hsv = {0, rgb_matrix_config.hsv.s, rgb_matrix_config.hsv.v};
+ hsv_t hsv = rgb_matrix_config.hsv;
// Take the shortest path between hues
- int16_t deltaH = ((rgb_matrix_config.hsv.h + 180) % 360 - rgb_matrix_config.hsv.h) / 4;
+ int16_t deltaH = ((hsv.h + 180) % 360 - hsv.h) / 4;
if (deltaH > 127) {
deltaH -= 256;
} else if (deltaH < -127) {
deltaH += 256;
}
- hsv.h = rgb_matrix_config.hsv.h + (deltaH * (random8() & 0x03));
+ hsv.h += (deltaH * random8_max(3));
rgb_t rgb = rgb_matrix_hsv_to_rgb(hsv);
rgb_matrix_set_color(i, rgb.r, rgb.g, rgb.b);
}
bool RAINDROPS(effect_params_t* params) {
+ static uint16_t index = RGB_MATRIX_LED_COUNT + 1;
+
+ // Periodic trigger for LED change
+ if ((params->iter == 0) && (scale16by8(g_rgb_timer, qadd8(rgb_matrix_config.speed, 16)) % 10 == 0)) {
+ index = random8_max(RGB_MATRIX_LED_COUNT);
+ }
+
RGB_MATRIX_USE_LIMITS(led_min, led_max);
- if (!params->init) {
- // Change one LED every tick, make sure speed is not 0
- if (scale16by8(g_rgb_timer, qadd8(rgb_matrix_config.speed, 16)) % 10 == 0) {
- raindrops_set_color(random8_max(RGB_MATRIX_LED_COUNT), params);
- }
- } else {
- for (int i = led_min; i < led_max; i++) {
+ if (params->init) {
+ for (uint8_t i = led_min; i < led_max; i++) {
raindrops_set_color(i, params);
}
}
+ // Change LED once and set index out of range till next trigger
+ else if (led_min <= index && index < led_max) {
+ raindrops_set_color(index, params);
+ index = RGB_MATRIX_LED_COUNT + 1;
+ }
return rgb_matrix_check_finished_leds(led_max);
}
diff --git a/quantum/rgb_matrix/animations/starlight_anim.h b/quantum/rgb_matrix/animations/starlight_anim.h
index 742e843b57..c4f943c5ce 100644
--- a/quantum/rgb_matrix/animations/starlight_anim.h
+++ b/quantum/rgb_matrix/animations/starlight_anim.h
@@ -2,7 +2,9 @@
RGB_MATRIX_EFFECT(STARLIGHT)
# ifdef RGB_MATRIX_CUSTOM_EFFECT_IMPLS
-void set_starlight_color(uint8_t i, effect_params_t* params) {
+static void set_starlight_color(uint8_t i, effect_params_t* params) {
+ if (!HAS_ANY_FLAGS(g_led_config.flags[i], params->flags)) return;
+
uint16_t time = scale16by8(g_rgb_timer, rgb_matrix_config.speed / 8);
hsv_t hsv = rgb_matrix_config.hsv;
hsv.v = scale8(abs8(sin8(time) - 128) * 2, hsv.v);
@@ -11,21 +13,26 @@ void set_starlight_color(uint8_t i, effect_params_t* params) {
}
bool STARLIGHT(effect_params_t* params) {
- if (!params->init) {
- if (scale16by8(g_rgb_timer, qadd8(rgb_matrix_config.speed, 5)) % 5 == 0) {
- uint8_t rand_led = random8_max(RGB_MATRIX_LED_COUNT);
- set_starlight_color(rand_led, params);
- }
- return false;
+ static uint16_t index = RGB_MATRIX_LED_COUNT + 1;
+
+ // Periodic trigger for LED change
+ if ((params->iter == 0) && (scale16by8(g_rgb_timer, qadd8(rgb_matrix_config.speed, 5)) % 5 == 0)) {
+ index = random8_max(RGB_MATRIX_LED_COUNT);
}
RGB_MATRIX_USE_LIMITS(led_min, led_max);
- for (uint8_t i = led_min; i < led_max; i++) {
- RGB_MATRIX_TEST_LED_FLAGS();
- set_starlight_color(i, params);
+ if (params->init) {
+ for (uint8_t i = led_min; i < led_max; i++) {
+ set_starlight_color(i, params);
+ }
+ }
+ // Change LED once and set index out of range till next trigger
+ else if (led_min <= index && index < led_max) {
+ set_starlight_color(index, params);
+ index = RGB_MATRIX_LED_COUNT + 1;
}
return rgb_matrix_check_finished_leds(led_max);
}
# endif // RGB_MATRIX_CUSTOM_EFFECT_IMPLS
-#endif // ENABLE_RGB_MATRIX_STARLIGHT \ No newline at end of file
+#endif // ENABLE_RGB_MATRIX_STARLIGHT
diff --git a/quantum/rgb_matrix/animations/starlight_dual_hue_anim.h b/quantum/rgb_matrix/animations/starlight_dual_hue_anim.h
index 50ce5d6ab4..276b8c3fdf 100644
--- a/quantum/rgb_matrix/animations/starlight_dual_hue_anim.h
+++ b/quantum/rgb_matrix/animations/starlight_dual_hue_anim.h
@@ -2,31 +2,38 @@
RGB_MATRIX_EFFECT(STARLIGHT_DUAL_HUE)
# ifdef RGB_MATRIX_CUSTOM_EFFECT_IMPLS
-void set_starlight_dual_hue_color(uint8_t i, effect_params_t* params) {
+static void set_starlight_dual_hue_color(uint8_t i, effect_params_t* params) {
+ if (!HAS_ANY_FLAGS(g_led_config.flags[i], params->flags)) return;
+
uint16_t time = scale16by8(g_rgb_timer, rgb_matrix_config.speed / 8);
hsv_t hsv = rgb_matrix_config.hsv;
hsv.v = scale8(abs8(sin8(time) - 128) * 2, hsv.v);
- hsv.h = hsv.h + random8_max((30 + 1 - -30) + -30);
+ hsv.h = hsv.h + random8_max(31);
rgb_t rgb = rgb_matrix_hsv_to_rgb(hsv);
rgb_matrix_set_color(i, rgb.r, rgb.g, rgb.b);
}
bool STARLIGHT_DUAL_HUE(effect_params_t* params) {
- if (!params->init) {
- if (scale16by8(g_rgb_timer, qadd8(rgb_matrix_config.speed, 5)) % 5 == 0) {
- uint8_t rand_led = random8_max(RGB_MATRIX_LED_COUNT);
- set_starlight_dual_hue_color(rand_led, params);
- }
- return false;
+ static uint16_t index = RGB_MATRIX_LED_COUNT + 1;
+
+ // Periodic trigger for LED change
+ if ((params->iter == 0) && (scale16by8(g_rgb_timer, qadd8(rgb_matrix_config.speed, 5)) % 5 == 0)) {
+ index = random8_max(RGB_MATRIX_LED_COUNT);
}
RGB_MATRIX_USE_LIMITS(led_min, led_max);
- for (uint8_t i = led_min; i < led_max; i++) {
- RGB_MATRIX_TEST_LED_FLAGS();
- set_starlight_dual_hue_color(i, params);
+ if (params->init) {
+ for (uint8_t i = led_min; i < led_max; i++) {
+ set_starlight_dual_hue_color(i, params);
+ }
+ }
+ // Change LED once and set index out of range till next trigger
+ else if (led_min <= index && index < led_max) {
+ set_starlight_dual_hue_color(index, params);
+ index = RGB_MATRIX_LED_COUNT + 1;
}
return rgb_matrix_check_finished_leds(led_max);
}
# endif // RGB_MATRIX_CUSTOM_EFFECT_IMPLS
-#endif // ENABLE_RGB_MATRIX_STARLIGHT_DUAL_HUE \ No newline at end of file
+#endif // ENABLE_RGB_MATRIX_STARLIGHT_DUAL_HUE
diff --git a/quantum/rgb_matrix/animations/starlight_dual_sat_anim.h b/quantum/rgb_matrix/animations/starlight_dual_sat_anim.h
index 6def4eea09..e063658982 100644
--- a/quantum/rgb_matrix/animations/starlight_dual_sat_anim.h
+++ b/quantum/rgb_matrix/animations/starlight_dual_sat_anim.h
@@ -2,31 +2,38 @@
RGB_MATRIX_EFFECT(STARLIGHT_DUAL_SAT)
# ifdef RGB_MATRIX_CUSTOM_EFFECT_IMPLS
-void set_starlight_dual_sat_color(uint8_t i, effect_params_t* params) {
+static void set_starlight_dual_sat_color(uint8_t i, effect_params_t* params) {
+ if (!HAS_ANY_FLAGS(g_led_config.flags[i], params->flags)) return;
+
uint16_t time = scale16by8(g_rgb_timer, rgb_matrix_config.speed / 8);
hsv_t hsv = rgb_matrix_config.hsv;
hsv.v = scale8(abs8(sin8(time) - 128) * 2, hsv.v);
- hsv.s = hsv.s + random8_max((30 + 1 - -30) + -30);
+ hsv.s = hsv.s + random8_max(31);
rgb_t rgb = rgb_matrix_hsv_to_rgb(hsv);
rgb_matrix_set_color(i, rgb.r, rgb.g, rgb.b);
}
bool STARLIGHT_DUAL_SAT(effect_params_t* params) {
- if (!params->init) {
- if (scale16by8(g_rgb_timer, qadd8(rgb_matrix_config.speed, 5)) % 5 == 0) {
- uint8_t rand_led = random8_max(RGB_MATRIX_LED_COUNT);
- set_starlight_dual_sat_color(rand_led, params);
- }
- return false;
+ static uint16_t index = RGB_MATRIX_LED_COUNT + 1;
+
+ // Periodic trigger for LED change
+ if ((params->iter == 0) && (scale16by8(g_rgb_timer, qadd8(rgb_matrix_config.speed, 5)) % 5 == 0)) {
+ index = random8_max(RGB_MATRIX_LED_COUNT);
}
RGB_MATRIX_USE_LIMITS(led_min, led_max);
- for (uint8_t i = led_min; i < led_max; i++) {
- RGB_MATRIX_TEST_LED_FLAGS();
- set_starlight_dual_sat_color(i, params);
+ if (params->init) {
+ for (uint8_t i = led_min; i < led_max; i++) {
+ set_starlight_dual_sat_color(i, params);
+ }
+ }
+ // Change LED once and set index out of range till next trigger
+ else if (led_min <= index && index < led_max) {
+ set_starlight_dual_sat_color(index, params);
+ index = RGB_MATRIX_LED_COUNT + 1;
}
return rgb_matrix_check_finished_leds(led_max);
}
# endif // RGB_MATRIX_CUSTOM_EFFECT_IMPLS
-#endif // ENABLE_RGB_MATRIX_STARLIGHT_DUAL_SAT \ No newline at end of file
+#endif // ENABLE_RGB_MATRIX_STARLIGHT_DUAL_SAT
diff --git a/readme.md b/readme.md
index 62aed12066..e5c0d41b7b 100644
--- a/readme.md
+++ b/readme.md
@@ -1,3 +1,7 @@
+# THIS IS THE DEVELOP BRANCH
+
+Warning- This is the `develop` branch of QMK Firmware. You may encounter broken code here. Please see [Breaking Changes](https://docs.qmk.fm/#/breaking_changes) for more information.
+
# Quantum Mechanical Keyboard Firmware
[![Current Version](https://img.shields.io/github/tag/qmk/qmk_firmware.svg)](https://github.com/qmk/qmk_firmware/tags)
diff --git a/tmk_core/protocol/chibios/usb_main.c b/tmk_core/protocol/chibios/usb_main.c
index 2a287e0d98..5a5354416f 100644
--- a/tmk_core/protocol/chibios/usb_main.c
+++ b/tmk_core/protocol/chibios/usb_main.c
@@ -325,18 +325,10 @@ static bool usb_requests_hook_cb(USBDriver *usbp) {
return false;
}
-static __attribute__((unused)) void dummy_cb(USBDriver *usbp) {
- (void)usbp;
-}
-
static const USBConfig usbcfg = {
usb_event_cb, /* USB events callback */
usb_get_descriptor_cb, /* Device GET_DESCRIPTOR request callback */
usb_requests_hook_cb, /* Requests hook callback */
-#if STM32_USB_USE_OTG1 == TRUE || STM32_USB_USE_OTG2 == TRUE
- dummy_cb, /* Workaround for OTG Peripherals not servicing new interrupts
- after resuming from suspend. */
-#endif
};
void init_usb_driver(USBDriver *usbp) {
diff --git a/keyboards/kradoindustries/promenade/keymaps/default/keymap.c b/keyboards/kradoindustries/promenade/keymaps/default/keymap.c
index aef0f28161..be8401e608 100644
--- a/keyboards/kradoindustries/promenade/keymaps/default/keymap.c
+++ b/keyboards/kradoindustries/promenade/keymaps/default/keymap.c
@@ -26,19 +26,19 @@ const uint16_t PROGMEM keymaps[][MATRIX_ROWS][MATRIX_COLS] = {
* .-----------------------------------------------------------------------------------------------------------------------------.
* | ESC | 1 | 2 | 3 | 4 | 5 | - | = | 6 | 7 | 8 | 9 | 0 | BACKSP |
* |--------+--------+--------+--------+--------+--------+--------+--------+--------+--------+--------+--------+-----------------|
- * | TAB | Q | W | E | R | T | [ | ] | Y | U | I | O | P | ' |
+ * | TAB | Q | W | E | R | T | [ | ] | Y | U | I | O | P | \ |
* |--------+--------+--------+--------+--------+--------+--------+--------+--------+--------+--------+-----------------+--------|
* | CAP LK | A | S | D | F | G | | | H | J | K | L | ; | ENTER |
* |--------+--------+--------+--------+--------+--------+--------+--------+--------+--------+--------------------------+--------|
* | LSHIFT | Z | X | C | V | B | END | PG DN | N | M | , | . | / | RSHIFT |
* |--------+--------+--------+--------+--------+-----------------+--------+--------+--------+-----------------+--------+--------|
- * | LCTRL | LGUI | FN | LALT | SPACE | SPACE | SPACE | SPACE | SPACE | LEFT | DOWN | UP | RIGHT | RCTRL |
+ * | LCTRL | LGUI | LALT | FN | SPACE | SPACE | SPACE | SPACE | LEFT | DOWN | UP | RIGHT | RCTRL |
* '-----------------------------------------------------------------------------------------------------------------------------'
*/
[_BASE] = LAYOUT_all(
KC_ESC, KC_1, KC_2, KC_3, KC_4, KC_5, KC_MINS, KC_EQL, KC_6, KC_7, KC_8, KC_9, KC_0, KC_BSPC,
- KC_TAB, KC_Q, KC_W, KC_E, KC_R, KC_T, KC_LBRC, KC_RBRC, KC_Y, KC_U, KC_I, KC_O, KC_P, KC_QUOT,
- KC_CAPS, KC_A, KC_S, KC_D, KC_F, KC_G, KC_H, KC_J, KC_K, KC_L, KC_SCLN, KC_ENT,
+ KC_TAB, KC_Q, KC_W, KC_E, KC_R, KC_T, KC_LBRC, KC_RBRC, KC_Y, KC_U, KC_I, KC_O, KC_P, KC_BSLS,
+ KC_CAPS, KC_A, KC_S, KC_D, KC_F, KC_G, KC_HOME, KC_PGUP, KC_H, KC_J, KC_K, KC_L, KC_SCLN, KC_ENT,
KC_LSFT, KC_Z, KC_X, KC_C, KC_V, KC_B, KC_END, KC_PGDN, KC_N, KC_M, KC_COMM, KC_DOT, KC_SLSH, KC_RSFT,
KC_LCTL, KC_LGUI, KC_LALT, MO(_FN), KC_SPC, KC_SPC, KC_SPC, KC_SPC, KC_LEFT, KC_DOWN, KC_UP, KC_RGHT, KC_RCTL
),
@@ -47,20 +47,20 @@ const uint16_t PROGMEM keymaps[][MATRIX_ROWS][MATRIX_COLS] = {
* .-----------------------------------------------------------------------------------------------------------------------------.
* | ` | F1 | F2 | F3 | F4 | F5 | F6 | F7 | F8 | F9 | F10 | F11 | F12 | DEL |
* |--------+--------+--------+--------+--------+--------+--------+--------+--------+--------+--------+--------+-----------------|
- * | | Home | Up | End | PgUp | | | | | | | | PRT SC | |
+ * | | HOME | UP | END | PG UP | | | | | | | | PRT SC | |
* |--------+--------+--------+--------+--------+--------+--------+--------+--------+--------+--------+-----------------+--------|
- * | | Left | Down | Right | PgDn | | | | | | | | | Reset |
+ * | | LEFT | DOWN | RIGHT | PG DN | | | | | | | | ' | RGB Off|
* |--------+--------+--------+--------+--------+--------+--------+--------+--------+--------+--------------------------+--------|
* | | | | | | | | | | MUTE | VOL DN | VOL UP | \ | |
* |--------+--------+--------+--------+--------+-----------------+--------+--------+--------+-----------------+--------+--------|
- * | | | | | | | | | | | | | | Reset |
+ * | | | | | | ENTER | ENTER | BACKSP | | | | | Reset |
* '-----------------------------------------------------------------------------------------------------------------------------'
*/
[_FN] = LAYOUT_all(
KC_GRV, KC_F1, KC_F2, KC_F3, KC_F4, KC_F5, KC_F6, KC_F7, KC_F8, KC_F9, KC_F10, KC_F11, KC_F12, KC_DEL,
_______, KC_HOME, KC_UP, KC_END, KC_PGUP, _______, _______, _______, _______, _______, _______, _______, KC_PSCR, _______,
- _______, KC_LEFT, KC_DOWN, KC_RGHT, KC_PGDN, _______, _______, _______, _______, _______, _______, QK_BOOT,
+ _______, KC_LEFT, KC_DOWN, KC_RGHT, KC_PGDN, _______, _______, _______, _______, _______, _______, _______, KC_QUOT, UG_TOGG,
_______, _______, _______, _______, _______, _______, _______, _______, _______, KC_MUTE, KC_VOLD, KC_VOLU, KC_BSLS, _______,
- _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, QK_BOOT
+ _______, _______, _______, _______, _______, KC_ENT, KC_ENT, KC_BSPC, _______, _______, _______, _______, QK_BOOT
)
};
@@ -26,19 +26,19 @@ const uint16_t PROGMEM keymaps[][MATRIX_ROWS][MATRIX_COLS] = {
* |--------+--------+--------+--------+--------+--------+--------+--------+--------+--------+--------+-----------------+--------|
- * | CAP LK | A | S | D | F | G | | | H | J | K | L | ; | ENTER |
+ * | CAP LK | A | S | D | F | G | HOME | PG UP | H | J | K | L | ; | ENTER |
* |--------+--------+--------+--------+--------+--------+--------+--------+--------+--------+--------------------------+--------|
* | LSHIFT | Z | X | C | V | B | END | PG DN | N | M | , | . | / | RSHIFT |